/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970.h
*
* This File contains PGA970 Register Definitions
*
* @path $(CSLPATH)\PGA970\source\chip\inc
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 05-Sept-2014 mf: Modified TusharB. PGA970 registers.
* =========================================================================== */

#ifndef PGA970_H
#define PGA970_H

#ifdef __cplusplus
extern "C" {
#endif

#define RAM_MBIST_CONTROL          (*((VUC *)0x40000502))
#define RAM_MBIST_STATUS           (*((VUC *)0x40000503))
#define CLK_CTRL_STATUS            (*((VUC *)0x40000504))
#define FRAM_STATUS                (*((VUC *)0x40000505))
#define DIG_IF_CTRL                (*((VUC *)0x40000506))

#define OWI_ERROR_STATUS_LO        (*((VUC *)0x40000508))
#define OWI_ERROR_STATUS_HI        (*((VUC *)0x40000509))
#define OWI_ERROR_STATUS           (*((VUS *)0x40000508))
#define OWI_INTERRUPT              (*((VUC *)0x4000050A))
#define OWI_INTERRUPT_ENABLE       (*((VUC *)0x4000050B))

#define FRAM_PAGE_ADDR             (*((VUC *)0x40000518))
#define DATA_WAVE_PAGE_ADDR        (*((VUC *)0x40000519))
#define DEVRAM_PAGE_ADDR           (*((VUC *)0x4000051A))

#define WDOG_CTRL_STAT             (*((VUC *)0x4000051C))
#define WDOG_TRIG_HIGH             (*((VUC *)0x4000051D))
#define WDOG_TRIG_LOW              (*((VUC *)0x4000051E))

#define DEMOD1_CONFIG              (*((VUC *)0x40000520))
#define DEMOD2_CONFIG              (*((VUC *)0x40000521))
#define ADC3_CONFIG                (*((VUC *)0x40000522))
#define S1_S2_DEMOD_CFG_1          (*((VUC *)0x40000524))
#define S3_ADC_CFG_1               (*((VUC *)0x40000526))
#define S1_CFG                     (*((VUC *)0x40000527)) 
#define S2_CFG                     (*((VUC *)0x40000528))
#define S1_S2_CFG                  (*((VUC *)0x40000529))  
#define S3_CFG                     (*((VUC *)0x4000052A))
#define S3_CFG_1                   (*((VUC *)0x4000052B))     

#define DAC_REG0_1                 (*((VUC *)0x40000530))
#define DAC_REG0_2                 (*((VUC *)0x40000531))
#define DAC_REG0                   (*((VUS *)0x40000530))
#define DAC_CTRL_STATUS            (*((VUC *)0x40000538))
#define DAC_CONFIG                 (*((VUC *)0x40000539))
#define DAC_LPBK_CTRL              (*((VUC *)0x4000053A))
#define OP_STAGE_CTRL              (*((VUC *)0x4000053B))

#define LVDT_OP_CTRL               (*((VUC *)0x4000053C))
#define LVDT_LPBK_CTRL             (*((VUC *)0x4000053D))

#define CCS_CTRL                   (*((VUC *)0x4000053E))

#define AFEDIAG_CFG                (*((VUC *)0x40000545))
#define ALPWR                      (*((VUC *)0x40000550))   // Address of register ALPWR
#define DLPWR                      (*((VUC *)0x40000554))
#define PSMON1                     (*((VUC *)0x40000558))
#define PSMON2                     (*((VUC *)0x40000559))
#define PSMON                      (*((VUS *)0x40000558))
#define AFEDIAG                    (*((VUC *)0x4000055B))
#define AFEDIAG1                   (*((VUC *)0x4000055C))
#define AFEDIAG3                   (*((VUC *)0x4000055E))
#define AFEDIAG4                   (*((VUC *)0x4000055F))

#define TOPDIG_MUX_SEL             (*((VUC *)0x40000560))

#define AMUX_ACT                   (*((VUC *)0x40000564))
#define AMUX_TIN_MUX_CTRL          (*((VUC *)0x40000565))
#define AMUX_TOUT_MUX_CTRL         (*((VUC *)0x40000566))
#define AMUX_CTRL                  (*((VUC *)0x40000567))

#define WAVEFORM_GEN_CTRL          (*((VUC *)0x40000578))
#define WAVEFORM_TABLE_LEN         (*((VUC *)0x4000057A))
#define WAVEFORM_DAC_OFFSET_0      (*((VUC *)0x4000057C))
#define WAVEFORM_DAC_OFFSET_1      (*((VUC *)0x4000057D))
#define WAVEFORM_DAC_OFFSET        (*((VUS *)0x4000057C))

#define FAST_DIV_NUMERATOR         (*((VSL *)0x40000580))
#define FAST_DIV_DENOMINATOR       (*((VSL *)0x40000584))
#define FAST_DIV_CTRL              (*((VUC *)0x40000588))
#define FAST_DIV_STAT              (*((VUC *)0x4000058A))
 
#define FAST_DIV_QUOTIENT          (*((VSL *)0x4000058C))
#define FAST_DIV_REMAINDER         (*((VSL *)0x40000590))

#define DEMOD1_BPF_B1              (*((VUL *)0x40000598))
#define DEMOD1_BPF_A2              (*((VUL *)0x4000059C))
#define DEMOD1_BPF_A3              (*((VUL *)0x400005A0))
#define DEMOD1_LPF_B1             (*((VS2 *)0x400005A4))
#define DEMOD1_LPF_A2             (*((VS2 *)0x400005A8))

#define DEMOD2_BPF_B1              (*((VUL *)0x400005B4))
#define DEMOD2_BPF_A2              (*((VUL *)0x400005B8))
#define DEMOD2_BPF_A3              (*((VUL *)0x400005BC))
#define DEMOD2_LPF_B1             (*((VS2 *)0x400005C0))
#define DEMOD2_LPF_A2             (*((VS2 *)0x400005C4))

#define ADC3_VI_LPF_B1             (*((VS2 *)0x400005CC))
#define ADC3_VI_LPF_A2             (*((VS2 *)0x400005CE))
#define ADC3_PTAT_LPF_B1           (*((VS2 *)0x400005E0))
#define ADC3_PTAT_LPF_A2           (*((VS2 *)0x400005E2))

#define DAC_SIN_NDS1               (*((VUS *)0x400005E4))
#define DAC_SIN_NDS2               (*((VUS *)0x400005E6))

#define REVISION_ID1               (*((VUC *)0x40000400))
#define REVISION_ID2               (*((VUC *)0x40000401))
#define REVISION_ID                (*((VUS *)0x40000400))

#define COM_MCU_TO_DIF_B1          (*((VUC *)0x40000404))
#define COM_MCU_TO_DIF_B2          (*((VUC *)0x40000405))
#define COM_MCU_TO_DIF_B           (*((VUS *)0x40000404))
#define COM_TX_STATUS              (*((VUC *)0x40000406))
#define COM_DIF_TO_MCU_B1          (*((VUC *)0x40000408))
#define COM_DIF_TO_MCU_B2          (*((VUC *)0x40000409))
#define COM_DIF_TO_MCU_B           (*((VUS *)0x40000408))
#define COM_RX_STATUS              (*((VUC *)0x4000040A))
#define COM_RX_INT_ENABLE          (*((VUC *)0x4000040B))

#define MICRO_INTERFACE_CONTROL    (*((VUC *)0x4000040C))
#define SECLOCK                    (*((VUC *)0x4000040D))

#define DEMOD1_DATA                (*((VSL *)0x40000410))
#define DEMOD2_DATA                (*((VSL *)0x40000414))
#define ADC3_VI_DATA               (*((VSL *)0x4000041C))
#define ADC3_PTAT_DATA             (*((VSL *)0x40000428))
#define DEMOD1_PH1_DATA            (*((VSL *)0x4000042C))
#define DEMOD1_PH2_DATA            (*((VSL *)0x40000430))
#define DEMOD2_PH1_DATA            (*((VSL *)0x40000434))
#define DEMOD2_PH2_DATA            (*((VSL *)0x40000438))
#define ADC3_COIL3_DATA            (*((VSL *)0x4000043C))

#define REMAP                      (*((VUC *)0x40000220))

#define GPIO_INPUT                 (*((VUC *)0x40000230))
#define GPIO_OUTPUT                (*((VUC *)0x40000231))
#define GPIO_DIR                   (*((VUC *)0x40000232))
#define GPIO_OPTYPE                (*((VUC *)0x40000233))

#define PIN_MUX                    (*((VUC *)0x40000240))

/*FRAM TEXT area*/
#define FRAM_TEXT_START_ADDRESS    (0x00000000)
#define FRAM_TEXT_END_ADDRESS      (0x000017FF)
#define FRAM_TEXT_AREA_SIZE        (0x1800)

/*FRAM DATA area*/
#define FRAM_DATA_START_ADDRESS    (0x00001800)
#define FRAM_DATA_END_ADDRESS      (0x00001EFF)             // reduced by 256 bytes to make Nigel's data area

/* Nigel's data area */                                     // 256 bytes reserved for Nigel's data area
#define NDATA_START_ADDRESS        (0x00001F00)
#define NDATA_END_ADDRESS          (0x00001FFF)

/*Development Ram start address*/
#define DEVRAM_START_ADDRESS       (0x21000000)
#ifdef __cplusplus
}
#endif

#endif /* PGA970_H */
