/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_ADC.h
*
* Header file for pga970_adc.c
*
* @path $(CSLPATH)\PGA970\source\chip\inc
*
* @rev 1.0
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 29-Apr-2015 mf: Modified AbhimanyuK. Added ADC module related information.
* =========================================================================== */

#ifndef PGA970_ADC_H
#define PGA970_ADC_H

#ifdef __cplusplus
extern "C" {
#endif



/* Bit definition of DEMOD1_CONFIG register */
#define	DEMOD1_EN                 (1 << 0)
#define DEMOD1_DECI_RATE_128      (0 << 2)
#define DEMOD1_DECI_RATE_256      (1 << 2)

#define	DISABLE_DEMOD1_EN         (0 << 0)

/* Bit definition of DEMOD2_CONFIG register */
#define	DEMOD2_EN                 (1 << 0)
#define DEMOD2_DECI_RATE_128      (0 << 2)
#define DEMOD2_DECI_RATE_256      (1 << 2)

#define	DISABLE_DEMOD2_EN         (0 << 0)

/* Bit definition of ADC3_CONFIG register */
#define	ADC3_EN                   (1 << 0)
#define	DISABLE_ADC3_EN           (0 << 0)

/* Bit definition of S1_S2_DEMOD_CFG_1 register */
#define	S1_S2_RESET_MOD           (1 << 0)
#define	S1_S2_RESET_CLK           (1 << 1)
#define S1_S2_DEMOD_EN            (1 << 3)

#define NO_S1_S2_RESET_MOD        (0 << 0)
#define NO_S1_S2_RESET_CLK        (0 << 1)
#define DISABLE_S1_S2_DEMOD_EN    (0 << 3)

/* Bit definition of S3_ADC_CFG_1 register */
#define	S3_RESET_MOD            (1 << 0)
#define	S3_RESET_CLK            (1 << 1)
#define	S3_ADC_EN               (1 << 3)

#define NO_S3_RESET_MOD         (0 << 0)
#define NO_S3_RESET_CLK         (0 << 1)
#define	S3_ADC_DISABLE          (0 << 3)

/* Bit definition of S1_CFG register */
#define	S1_GAIN_1_00_V_V            (0 << 1) | (0 << 0)
#define	S1_GAIN_1_33_V_V            (0 << 1) | (1 << 0)
#define	S1_GAIN_1_67_V_V            (1 << 1) | (0 << 0)
#define	S1_GAIN_2_00_V_V            (1 << 1) | (1 << 0)
#define	S1_GAIN_SINGLE_END          (1 << 6)
#define	S1_GAIN_DIFFERENTIAL        (0 << 6)
#define	S1_INV                      (1 << 7)
#define NO_S1_INV                   (0 << 7)

/* Bit definition of S2_CFG register */
#define	S2_GAIN_1_00_V_V            (0 << 1) | (0 << 0)
#define	S2_GAIN_1_33_V_V            (0 << 1) | (1 << 0)
#define	S2_GAIN_1_67_V_V            (1 << 1) | (0 << 0)
#define	S2_GAIN_2_00_V_V            (1 << 1) | (1 << 0)
#define	S2_GAIN_SINGLE_END          (1 << 6)
#define	S2_GAIN_DIFFERENTIAL        (0 << 6)
#define	S2_INV                      (1 << 7)
#define NO_S2_INV                   (0 << 7)

/* Bit definition of S1_S2_CFG register */
#define	BIAS_VCM_CTRL_0_0       (0 << 1) | (0 << 0)
#define	BIAS_VCM_CTRL_0_1       (0 << 1) | (1 << 0)
#define	BIAS_VCM_CTRL_1_0       (1 << 1) | (0 << 0)
#define	BIAS_VCM_CTRL_1_1       (1 << 1) | (1 << 0)
#define	VCM_ENABLE              (1 << 2)
#define	VCM_DISABLE             (0 << 2)

/* Bit definition of S3_CFG register */
#define	VI_GAIN_1_V_V           (0 << 7) | (0 << 6)
#define	VI_GAIN_1_33_V_V        (0 << 7) | (1 << 6)
#define	VI_GAIN_2_V_V           (1 << 7) | (0 << 6)
#define	VI_GAIN_5_V_V           (1 << 7) | (1 << 6)

/* Bit definition of S3_CFG_1 register */
#define	PTAT_GAIN_1_V_V         (0 << 1) | (0 << 0)
#define	PTAT_GAIN_1_33_V_V      (0 << 1) | (1 << 0)
#define	PTAT_GAIN_2_V_V         (1 << 1) | (0 << 0)
#define	PTAT_GAIN_5_V_V         (1 << 1) | (1 << 0)

#define	S3_OUTPUT_INV           (1 << 7)
#define NO_S3_OUTPUT_INV        (0 << 7)

/* Bit definition of ALPWR register */
#define SHUT_DOWN               (1 << 0)    // Bit 0 = SD
#define ADC_EN_VREF_BUF         (1 << 2)    // Bit 2 = ADC_EN_VREF
#define GATE_CTRL_SD_DISABLE    (1 << 4)    // BIT 4 = GATE_CTRL_SD
#define POWER_UP_PT_PGA_FD      (0 << 0)    // Bit 0 = SD
#define ADC_DIS_VREF            (0 << 2)    // Bit 2 = ADC_EN_VREF
#define GATE_CTRL_SD_ENABLE     (0 << 4)    // BIT 4 = GATE_CTRL_SD

/* Bit definition of ALPWR register */
//#define SHUT_DOWN                   (1 << 0)    //Why is this defined again? NJH 10/01/20. Now commented out
//#define POWER_UP_PT_PGA_FD          (0 << 0)    //Why is this defined again? NJH 10/01/20. Now commented out

#define ADC_EN_VREF                 (1 << 2)
#define ADC_DIS_VREF                (0 << 2)

#define GATE_CTRL_SD_DISABLE        (1 << 4)
#define GATE_CTRL_SD_ENABLE         (0 << 4)

/*ADC1/ADC2 BPF register configuration*/
#define ADC12_BPF_CF1KHZ_B20HZ_B1     0x41E
#define ADC12_BPF_CF1KHZ_B20HZ_A2     0xFFFA97
#define ADC12_BPF_CF1KHZ_B20HZ_A3     0xFFF7C4

#define ADC12_BPF_CF1KHZ_B100HZ_B1    0x1495
#define ADC12_BPF_CF1KHZ_B100HZ_A2    0xFFEA21
#define ADC12_BPF_CF1KHZ_B100HZ_A3    0xFFD6D6

#define ADC12_BPF_CF1KHZ_B250HZ_B1    0x336E
#define ADC12_BPF_CF1KHZ_B250HZ_A2    0xFFCB4C
#define ADC12_BPF_CF1KHZ_B250HZ_A3    0xFF9923

#define ADC12_BPF_CF2KHZ_B20HZ_B1     0x41E
#define ADC12_BPF_CF2KHZ_B20HZ_A2     0xFFF6B5
#define ADC12_BPF_CF2KHZ_B20HZ_A3     0xFFF7C4

#define ADC12_BPF_CF2KHZ_B100HZ_B1    0x1495
#define ADC12_BPF_CF2KHZ_B100HZ_A2    0xFFE640
#define ADC12_BPF_CF2KHZ_B100HZ_A3    0xFFD6D6

#define ADC12_BPF_CF2KHZ_B250HZ_B1    0x336E
#define ADC12_BPF_CF2KHZ_B250HZ_A2    0xFFC76B
#define ADC12_BPF_CF2KHZ_B250HZ_A3    0xFF9923

#define ADC12_BPF_CF3KHZ_B20HZ_B1     0x41E
#define ADC12_BPF_CF3KHZ_B20HZ_A2     0xFFF03E
#define ADC12_BPF_CF3KHZ_B20HZ_A3     0xFFF7C4

#define ADC12_BPF_CF3KHZ_B100HZ_B1    0x1495
#define ADC12_BPF_CF3KHZ_B100HZ_A2    0xFFDFC8
#define ADC12_BPF_CF3KHZ_B100HZ_A3    0xFFD6D6

#define ADC12_BPF_CF3KHZ_B250HZ_B1    0x336E
#define ADC12_BPF_CF3KHZ_B250HZ_A2    0xFFC0F5
#define ADC12_BPF_CF3KHZ_B250HZ_A3    0xFF9923

#define ADC12_BPF_CF4KHZ_B20HZ_B1     0x41E
#define ADC12_BPF_CF4KHZ_B20HZ_A2     0xFFE730
#define ADC12_BPF_CF4KHZ_B20HZ_A3     0xFFF7C4

#define ADC12_BPF_CF4KHZ_B100HZ_B1    0x1495
#define ADC12_BPF_CF4KHZ_B100HZ_A2    0xFFD6BB
#define ADC12_BPF_CF4KHZ_B100HZ_A3    0xFFD6D6

#define ADC12_BPF_CF4KHZ_B250HZ_B1    0x336E
#define ADC12_BPF_CF4KHZ_B250HZ_A2    0xFFB7E8
#define ADC12_BPF_CF4KHZ_B250HZ_A3    0xFF9923

#define ADC12_BPF_CF5KHZ_B20HZ_B1     0x41E
#define ADC12_BPF_CF5KHZ_B20HZ_A2     0xFFDB8C
#define ADC12_BPF_CF5KHZ_B20HZ_A3     0xFFF7CF

#define ADC12_BPF_CF5KHZ_B100HZ_B1    0x1495
#define ADC12_BPF_CF5KHZ_B100HZ_A2    0xFFCB18
#define ADC12_BPF_CF5KHZ_B100HZ_A3    0xFFD6D6

#define ADC12_BPF_CF5KHZ_B250HZ_B1    0x336E
#define ADC12_BPF_CF5KHZ_B250HZ_A2    0xFFAC47
#define ADC12_BPF_CF5KHZ_B250HZ_A3    0xFF9923

#define ADC12_BPF_CF6KHZ_B20HZ_B1     0x41E
#define ADC12_BPF_CF6KHZ_B20HZ_A2     0xFFCD52
#define ADC12_BPF_CF6KHZ_B20HZ_A3     0xFFF7C4

#define ADC12_BPF_CF6KHZ_B100HZ_B1    0x1495
#define ADC12_BPF_CF6KHZ_B100HZ_A2    0xFFBCDF
#define ADC12_BPF_CF6KHZ_B100HZ_A3    0xFFD6D6

#define ADC12_BPF_CF6KHZ_B250HZ_B1    0x336E
#define ADC12_BPF_CF6KHZ_B250HZ_A2    0xFF9E0F
#define ADC12_BPF_CF6KHZ_B250HZ_A3    0xFF9923

#define ADC12_BPF_CF7KHZ_B20HZ_B1     0x41E
#define ADC12_BPF_CF7KHZ_B20HZ_A2     0xFFBC82
#define ADC12_BPF_CF7KHZ_B20HZ_A3     0xFFF7C4

#define ADC12_BPF_CF7KHZ_B100HZ_B1    0x1495
#define ADC12_BPF_CF7KHZ_B100HZ_A2    0xFFAC10
#define ADC12_BPF_CF7KHZ_B100HZ_A3    0xFFD6D6

#define ADC12_BPF_CF7KHZ_B250HZ_B1    0x336E
#define ADC12_BPF_CF7KHZ_B250HZ_A2    0xFF8D43
#define ADC12_BPF_CF7KHZ_B250HZ_A3    0xFF9923

#define ADC12_BPF_CF8KHZ_B20HZ_B1     0x41E
#define ADC12_BPF_CF8KHZ_B20HZ_A2     0xFFA91D
#define ADC12_BPF_CF8KHZ_B20HZ_A3     0xFFF7C4

#define ADC12_BPF_CF8KHZ_B100HZ_B1    0x1495
#define ADC12_BPF_CF8KHZ_B100HZ_A2    0xFF98AC
#define ADC12_BPF_CF8KHZ_B100HZ_A3    0xFFD6D6

#define ADC12_BPF_CF8KHZ_B250HZ_B1    0x336E
#define ADC12_BPF_CF8KHZ_B250HZ_A2    0xFF79E1
#define ADC12_BPF_CF8KHZ_B250HZ_A3    0xFF9923

#define ADC12_BPF_CF9KHZ_B20HZ_B1     0x41E
#define ADC12_BPF_CF9KHZ_B20HZ_A2     0xFF9322
#define ADC12_BPF_CF9KHZ_B20HZ_A3     0xFFF7C4

#define ADC12_BPF_CF9KHZ_B100HZ_B1    0x1495
#define ADC12_BPF_CF9KHZ_B100HZ_A2    0xFF82B3
#define ADC12_BPF_CF9KHZ_B100HZ_A3    0xFFD6D6

#define ADC12_BPF_CF9KHZ_B250HZ_B1    0x336E
#define ADC12_BPF_CF9KHZ_B250HZ_A2    0xFF63EA
#define ADC12_BPF_CF9KHZ_B250HZ_A3    0xFF9923

#define ADC12_BPF_CF10KHZ_B20HZ_B1    0x41E
#define ADC12_BPF_CF10KHZ_B20HZ_A2    0xFF7A92
#define ADC12_BPF_CF10KHZ_B20HZ_A3    0xFFF7C4

#define ADC12_BPF_CF10KHZ_B100HZ_B1   0x1495
#define ADC12_BPF_CF10KHZ_B100HZ_A2   0xFF6A24
#define ADC12_BPF_CF10KHZ_B100HZ_A3   0xFFD6D6

#define ADC12_BPF_CF10KHZ_B250HZ_B1   0x336E
#define ADC12_BPF_CF10KHZ_B250HZ_A2   0xFF4B5F
#define ADC12_BPF_CF10KHZ_B250HZ_A3   0xFF9923

#define ADC12_BPF_CF11KHZ_B20HZ_B1    0x41E
#define ADC12_BPF_CF11KHZ_B20HZ_A2    0xFF5F6D
#define ADC12_BPF_CF11KHZ_B20HZ_A3    0xFFF7C4

#define ADC12_BPF_CF11KHZ_B100HZ_B1   0x1495
#define ADC12_BPF_CF11KHZ_B100HZ_A2   0xFF4F01
#define ADC12_BPF_CF11KHZ_B100HZ_A3   0xFFD6D6

#define ADC12_BPF_CF11KHZ_B250HZ_B1   0x336E
#define ADC12_BPF_CF11KHZ_B250HZ_A2   0xFF303F
#define ADC12_BPF_CF11KHZ_B250HZ_A3   0xFF9923

#define ADC12_BPF_CF12KHZ_B20HZ_B1    0x41E
#define ADC12_BPF_CF12KHZ_B20HZ_A2    0xFF41B3
#define ADC12_BPF_CF12KHZ_B20HZ_A3    0xFFF7C4

#define ADC12_BPF_CF12KHZ_B100HZ_B1   0x1495
#define ADC12_BPF_CF12KHZ_B100HZ_A2   0xFF3149
#define ADC12_BPF_CF12KHZ_B100HZ_A3   0xFFD6D6

#define ADC12_BPF_CF12KHZ_B250HZ_B1   0x336E
#define ADC12_BPF_CF12KHZ_B250HZ_A2   0xFF128A
#define ADC12_BPF_CF12KHZ_B250HZ_A3   0xFF9933

#define ADC12_BPF_CF13KHZ_B20HZ_B1    0x41E
#define ADC12_BPF_CF13KHZ_B20HZ_A2    0xFF2165
#define ADC12_BPF_CF13KHZ_B20HZ_A3    0xFFF7C4

#define ADC12_BPF_CF13KHZ_B100HZ_B1   0x1495
#define ADC12_BPF_CF13KHZ_B100HZ_A2   0xFF10FD
#define ADC12_BPF_CF13KHZ_B100HZ_A3   0xFFD6D6

#define ADC12_BPF_CF13KHZ_B250HZ_B1   0x336E
#define ADC12_BPF_CF13KHZ_B250HZ_A2   0xFEF242
#define ADC12_BPF_CF13KHZ_B250HZ_A3   0xFF9923

#define ADC12_BPF_CF14KHZ_B20HZ_B1    0x41E
#define ADC12_BPF_CF14KHZ_B20HZ_A2    0xFEFE83
#define ADC12_BPF_CF14KHZ_B20HZ_A3    0xFFF7C4

#define ADC12_BPF_CF14KHZ_B100HZ_B1   0x1495
#define ADC12_BPF_CF14KHZ_B100HZ_A2   0xFEEE1D
#define ADC12_BPF_CF14KHZ_B100HZ_A3   0xFFD6D6

#define ADC12_BPF_CF14KHZ_B250HZ_B1   0x336E
#define ADC12_BPF_CF14KHZ_B250HZ_A2   0xFECF66
#define ADC12_BPF_CF14KHZ_B250HZ_A3   0xFF9923

#define ADC12_BPF_CF15KHZ_B20HZ_B1    0x41E
#define ADC12_BPF_CF15KHZ_B20HZ_A2    0xFED90D
#define ADC12_BPF_CF15KHZ_B20HZ_A3    0xFFF7C4

#define ADC12_BPF_CF15KHZ_B100HZ_B1   0x1495
#define ADC12_BPF_CF15KHZ_B100HZ_A2   0xFEC8A9
#define ADC12_BPF_CF15KHZ_B100HZ_A3   0xFFD6D6

#define ADC12_BPF_CF15KHZ_B250HZ_B1   0x336E
#define ADC12_BPF_CF15KHZ_B250HZ_A2   0xFEA9F7
#define ADC12_BPF_CF15KHZ_B250HZ_A3   0xFF9923

#define ADC12_BPF_CF16KHZ_B20HZ_B1    0x41E
#define ADC12_BPF_CF16KHZ_B20HZ_A2    0xFEB103
#define ADC12_BPF_CF16KHZ_B20HZ_A3    0xFFF7C4

#define ADC12_BPF_CF16KHZ_B100HZ_B1   0x1495
#define ADC12_BPF_CF16KHZ_B100HZ_A2   0xFEA0A2
#define ADC12_BPF_CF16KHZ_B100HZ_A3   0xFFD6D6

#define ADC12_BPF_CF16KHZ_B250HZ_B1   0x336E
#define ADC12_BPF_CF16KHZ_B250HZ_A2   0xFE81F5
#define ADC12_BPF_CF16KHZ_B250HZ_A3   0xFF9923

#define ADC12_BPF_CF17KHZ_B20HZ_B1    0x41E
#define ADC12_BPF_CF17KHZ_B20HZ_A2    0xFE8667
#define ADC12_BPF_CF17KHZ_B20HZ_A3    0xFFF7C4

#define ADC12_BPF_CF17KHZ_B100HZ_B1   0x1495
#define ADC12_BPF_CF17KHZ_B100HZ_A2   0xFE7609
#define ADC12_BPF_CF17KHZ_B100HZ_A3   0xFFD6D6

#define ADC12_BPF_CF17KHZ_B250HZ_B1   0x336E
#define ADC12_BPF_CF17KHZ_B250HZ_A2   0xFE5761
#define ADC12_BPF_CF17KHZ_B250HZ_A3   0xFF9923

#define ADC12_BPF_CF18KHZ_B20HZ_B1    0x41E
#define ADC12_BPF_CF18KHZ_B20HZ_A2    0xFE5938
#define ADC12_BPF_CF18KHZ_B20HZ_A3    0xFFF7C4

#define ADC12_BPF_CF18KHZ_B100HZ_B1   0x1495
#define ADC12_BPF_CF18KHZ_B100HZ_A2   0xFE48DD
#define ADC12_BPF_CF18KHZ_B100HZ_A3   0xFFD6D6

#define ADC12_BPF_CF18KHZ_B250HZ_B1   0x336E
#define ADC12_BPF_CF18KHZ_B250HZ_A2   0xFE2A3A
#define ADC12_BPF_CF18KHZ_B250HZ_A3   0xFF9923

#define ADC12_BPF_CF19KHZ_B20HZ_B1    0x41E
#define ADC12_BPF_CF19KHZ_B20HZ_A2    0xFE2977
#define ADC12_BPF_CF19KHZ_B20HZ_A3    0xFFF7C4

#define ADC12_BPF_CF19KHZ_B100HZ_B1   0x1495
#define ADC12_BPF_CF19KHZ_B100HZ_A2   0xFE191F
#define ADC12_BPF_CF19KHZ_B100HZ_A3   0xFFD6D6

#define ADC12_BPF_CF19KHZ_B250HZ_B1   0x336E
#define ADC12_BPF_CF19KHZ_B250HZ_A2   0xFDFA82
#define ADC12_BPF_CF19KHZ_B250HZ_A3   0xFF9923

#define ADC12_BPF_CF20KHZ_B20HZ_B1    0x41E
#define ADC12_BPF_CF20KHZ_B20HZ_A2    0xFDF725
#define ADC12_BPF_CF20KHZ_B20HZ_A3    0xFFF7C4

#define ADC12_BPF_CF20KHZ_B100HZ_B1   0x1495
#define ADC12_BPF_CF20KHZ_B100HZ_A2   0xFDE6D0
#define ADC12_BPF_CF20KHZ_B100HZ_A3   0xFFD6D6

#define ADC12_BPF_CF20KHZ_B250HZ_B1   0x336E
#define ADC12_BPF_CF20KHZ_B250HZ_A2   0xFDC839
#define ADC12_BPF_CF20KHZ_B250HZ_A3   0xFF9923

/*ADC1/ADC2 LPF register configuration*/
#define ADC12_LPF_CF20HZ_OP128US_B1    0x105
#define ADC12_LPF_CF20HZ_OP128US_A2    0x7DF5

#define ADC12_LPF_CF20HZ_OP256US_B1    0x207
#define ADC12_LPF_CF20HZ_OP256US_A2    0x7BF2

#define ADC12_LPF_CF100HZ_OP128US_B1   0x4F3
#define ADC12_LPF_CF100HZ_OP128US_A2   0x7619

#define ADC12_LPF_CF100HZ_OP256US_B1   0x98C
#define ADC12_LPF_CF100HZ_OP256US_A2   0x6CE8

#define ADC12_LPF_CF250HZ_OP128US_B1   0xBBA
#define ADC12_LPF_CF250HZ_OP128US_A2   0x688B

#define ADC12_LPF_CF250HZ_OP256US_B1   0x15AC
#define ADC12_LPF_CF250HZ_OP256US_A2   0x54A8

/*ADC3 LPF register configuration*/
#define ADC3_LPF_CF20HZ_B1             0x187
#define ADC3_LPF_CF20HZ_A2             0x7CF3

#define ADC3_LPF_CF100HZ_B1            0x74A
#define ADC3_LPF_CF100HZ_A2            0x716C

#define ADC3_LPF_CF250HZ_B1            0x10E2
#define ADC3_LPF_CF250HZ_A2            0x5E3B

/*ADC_Count1 maximum value*/
#define ADC_COUNT1_16BIT_MAX_VAL     65535
/* ========================================================================== */
/**
 * S1_CONFIG() Configure ADC1 (Gain + single ended + output invert).
 *
 * @param x - Value to be written to S1_CFG register.
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
#define S1_CONFIG(x) (S1_CFG = (x))

/* ========================================================================== */
/**
 * S2_CONFIG() Configure ADC2 (Gain + single ended + output invert).
 *
 * @param x - Value to be written to S2_CFG register.
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
#define S2_CONFIG(x) (S2_CFG = (x))

/* ========================================================================== */
/**
 * S3_CONFIG() Configure ADC3 (Gain + single ended + output invert).
 *
 * @param x - Value to be written to S3_CFG register.
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
#define S3_CONFIG(x) (S3_CFG = (x))

/* ========================================================================== */
/**
 * S1_S2_CONFIG() Configure S1, S2 (BIAS_VCM_CTRL, VCM_EN).
 *
 * @param x - Value to be written to S1_S2_CFG register.
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
#define S1_S2_CONFIG(x) (S1_S2_CFG = (x))

/* ========================================================================== */
/**
 * S3_CFG_1_CONFIG() Configure S3 (S3_PTAT_GAIN,S3_INV).
 *
 * @param x - Value to be written to S3_CFG_1 register.
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
#define S3_CFG_1_CONFIG(x) (S3_CFG_1 = (x))

/* ========================================================================== */
/**
 * CONFIG_ALPWR() Configure ALPWR register.
 *
 * @param x - Value to be written to ALPWR register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_ALPWR(x)  (ALPWR = (x))

/* ========================================================================== */
/**
 * CONFIG_DEMOD1_BPF_B1() Configure DEMOD1_BPF_B1 register.
 *
 * @param x - Value to be written to DEMOD1_BPF_B1 register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_DEMOD1_BPF_B1(x)  (DEMOD1_BPF_B1 = (x))

/* ========================================================================== */
/**
 * CONFIG_DEMOD1_BPF_A2() Configure DEMOD1_BPF_A2 register.
 *
 * @param x - Value to be written to DEMOD1_BPF_A2 register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_DEMOD1_BPF_A2(x)  (DEMOD1_BPF_A2 = (x))

/* ========================================================================== */
/**
 * CONFIG_DEMOD1_BPF_A3() Configure DEMOD1_BPF_A3 register.
 *
 * @param x - Value to be written to DEMOD1_BPF_A3 register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_DEMOD1_BPF_A3(x)  (DEMOD1_BPF_A3 = (x))

/* ========================================================================== */
/**
 * CONFIG_DEMOD1_LPF_B1() Configure DEMOD1_LPF_B1 register.
 *
 * @param x - Value to be written to DEMOD1_LPF_B1 register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_DEMOD1_LPF_B1(x) (DEMOD1_LPF_B1 = (x))

/* ========================================================================== */
/**
 * CONFIG_DEMOD1_LPF_A2() Configure DEMOD1_LPF_A2 register.
 *
 * @param x - Value to be written to DEMOD1_LPF_A2 register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_DEMOD1_LPF_A2(x) (DEMOD1_LPF_A2 = (x))

/* ========================================================================== */
/**
 * CONFIG_DEMOD2_BPF_B1() Configure DEMOD2_BPF_B1 register.
 *
 * @param x - Value to be written to DEMOD2_BPF_B1 register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_DEMOD2_BPF_B1(x)  (DEMOD2_BPF_B1 = (x))

/* ========================================================================== */
/**
 * CONFIG_DEMOD2_BPF_A2() Configure DEMOD2_BPF_A2 register.
 *
 * @param x - Value to be written to DEMOD2_BPF_A2 register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_DEMOD2_BPF_A2(x)  (DEMOD2_BPF_A2 = (x))

/* ========================================================================== */
/**
 * CONFIG_DEMOD2_BPF_A3() Configure DEMOD2_BPF_A3 register.
 *
 * @param x - Value to be written to DEMOD2_BPF_A3 register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_DEMOD2_BPF_A3(x)  (DEMOD2_BPF_A3 = (x))

/* ========================================================================== */
/**
 * CONFIG_DEMOD2_LPF_B1() Configure DEMOD2_LPF_B1 register.
 *
 * @param x - Value to be written to DEMOD2_LPF_B1 register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_DEMOD2_LPF_B1(x) (DEMOD2_LPF_B1 = (x))

/* ========================================================================== */
/**
 * CONFIG_DEMOD2_LPF_A2() Configure DEMOD2_LPF_A2 register.
 *
 * @param x - Value to be written to DEMOD2_LPF_A2 register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_DEMOD2_LPF_A2(x) (DEMOD2_LPF_A2 = (x))

/* ========================================================================== */
/**
 * CONFIG_ADC3_VI_LPF_B1() Configure ADC3_VI_LPF_B1 register.
 *
 * @param x - Value to be written to ADC3_VI_LPF_B1 register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_ADC3_VI_LPF_B1(x)   (ADC3_VI_LPF_B1 = (x))

/* ========================================================================== */
/**
 * CONFIG_ADC3_VI_LPF_A2() Configure ADC3_VI_LPF_A2 register.
 *
 * @param x - Value to be written to ADC3_VI_LPF_A2 register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_ADC3_VI_LPF_A2(x)   (ADC3_VI_LPF_A2 = (x))

/* ========================================================================== */
/**
 * CONFIG_ADC3_PTAT_LPF_B1() Configure ADC3_PTAT_LPF_B1 register.
 *
 * @param x - Value to be written to ADC3_PTAT_LPF_B1 register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_ADC3_PTAT_LPF_B1(x)  (ADC3_PTAT_LPF_B1 = (x))

/* ========================================================================== */
/**
 * CONFIG_ADC3_PTAT_LPF_A2() Configure ADC3_PTAT_LPF_A2 register.
 *
 * @param x - Value to be written to ADC3_PTAT_LPF_A2 register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define CONFIG_ADC3_PTAT_LPF_A2(x)  (ADC3_PTAT_LPF_A2 = (x))


extern VS2 ADC_PchannelValue;  /* PADC Value */
extern VS2 ADC_TchannelValue;  /* TADC Value */
extern VUS ADC_Count1;         /* Track 2.048ms time*/
extern SL ratio;

/* ========================================================================== */
/**
 * ADC_Reset_Init() Initializes all ADC related global variables.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void ADC_Reset_Init(void);

/* ========================================================================== */
/**
 * ADC_Config() Configure ADC channels.
 *
 * @param adc1configValue Data to be written to ADC1_CONFIG register.
 *
 * @param adc2configValue Data to be written to ADC2_CONFIG register.
 *
 * @param adc3configValue Data to be written to ADC3_CONFIG register.
 *
 * @param s1s2Cfg1 Data to be written to S1_S2_DEMOD_CFG_1 register.
 *
 * @param s3Cfg1 Data to be written to S3_ADC_CFG_1 register.
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
void ADC_Config(UC adc1configValue, UC adc2configValue, UC adc3configValue,
                UC s1s2Cfg1, UC s3Cfg1);
/* ========================================================================== */
/**
 * ADC_Handler() Interrupt subroutine for ADC.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void ADC_Handler(void);
/* ========================================================================== */
/**
 * DEMOD1_BPF_config() Configure BPF of DEMOD1.
 *
 * @param B1config
 *
 * @param A2config
 *
 * @param A3config
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
void DEMOD1_BPF_config(UL B1config, UL A2config, UL A3config);

/* ========================================================================== */
/**
 * DEMOD1_LPF_config() Configure LPF of DEMOD1.
 *
 * @param B1config
 *
 * @param A2config
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
void DEMOD1_LPF_config(S2 B1configLPF, S2 A2config);

/* ========================================================================== */
/**
 * DEMOD2_BPF_config() Configure BPF of DEMOD2.
 *
 * @param B1config
 *
 * @param A2config
 *
 * @param A3config
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
void DEMOD2_BPF_config(UL B1config, UL A2config, UL A3config);

/* ========================================================================== */
/**
 * DEMOD2_LPF_config() Configure LPF of DEMOD2.
 *
 * @param B1config
 *
 * @param A2config
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
void DEMOD2_LPF_config(S2 B1config, S2 A2config);

/* ========================================================================== */
/**
 * ADC3_VI_LPF_Config() Configure LPF for VI of ADC3.
 *
 * @param B1config
 *
 * @param A2config
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
void ADC3_VI_LPF_Config(S2 B1config, S2 A2config);
/* ========================================================================== */
/**
 * ADC3_PTAT_LPF_Config() Configure LPF for PTAT of ADC3.
 *
 * @param B1config
 *
 * @param A2config
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
void ADC3_PTAT_LPF_Config(S2 B1config, S2 A2config);

#ifdef __cplusplus
}
#endif

#endif /* PGA970_ADC_H */
