/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_combuf.h
*
* Header file for pga970_combuf.c
*
* @path $(CSLPATH)\PGA970\source\chip\inc
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 27-Apr-2015 mf: Modified AbhimanyuK. Added COMBUF module related information.
* =========================================================================== */

#ifndef PGA970_COMBUF_H
#define PGA970_COMBUF_H

#ifdef __cplusplus
extern "C" {
#endif


#if (COMBUF_TESTING == 1)
/* Bit definition of COM_TX_STATUS register */
#define COMBUF_TXRDY             (1 << 0)

/* Bit definition of COM_RX_STATUS register */
#define COMBUF_RXRDY             (1 << 0)

/* Enable COMBUF Receive interrupt */
#define COMBUF_RXRDY_INT_ENABLE  (1 << 0)

/* ========================================================================== */
/**
 * COMBUF_RX_INT_ENABLE() Enable COMBUF receive interrupt.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define COMBUF_RX_INT_ENABLE()   (COM_RX_INT_ENABLE = COMBUF_RXRDY_INT_ENABLE)

/* ========================================================================== */
/**
 * COMBUF_RX_INT_ENABLE() Disable COMBUF receive interrupt.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define COMBUF_RX_INT_DISABLE()   (COM_RX_INT_ENABLE = 0x00)

/* ========================================================================== */
/**
 * COMBUF_RX_STATUS_CLEAR() Clear COMBUF receive status bit by writting '1'.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define COMBUF_RX_STATUS_CLEAR() (COM_RX_STATUS = 0x01)

extern VUC COMBUF_Flag;                        /* COMBUF ISR flag */
extern VUS COMBUF_Rx_Buf[1];                   /* COMBUF received value*/

/* ========================================================================== */
/**
 * COMBUF_Reset_Init() Initializes all COMBUF related global variables.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void COMBUF_Reset_Init(void);

/* ========================================================================== */
/**
 * COMBUF_Handler() Interrupt subroutine for COMBUF.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void COMBUF_Handler(void);

#endif /*#if (COMBUF_TESTING == 1)*/


#ifdef __cplusplus
}
#endif

#endif /* PGA970_COMBUF_H */
