/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_dac.h
*
* Header file for pga970_dac.c
*
* @path $(CSLPATH)\PGA970\source\chip\inc
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 08-Sept-2014 mf: Modified TusharB. Added DAC module related information.
* =========================================================================== */

#ifndef PGA970_DAC_H
#define PGA970_DAC_H

#ifdef __cplusplus
extern "C" {
#endif

/* DAC_CTRL_STATUS DAC control status register definitions */
#define	DAC_ENABLE                    (1 << 0)
#define	DAC_DISABLE                   (0 << 0)

/* DAC_CONFIG - DAC configuration register definitions */
#define DAC_RATIOMETRIC_MODE_ENABLE   (1 << 0)
#define DAC_ABSOLUTE_MODE_ENABLE      (0 << 0)

/* DAC_LPBK_CTRL - DAC loop-back control register definitions */
#define DAC_LOOPBACK_CONNECT          (1 << 0)
#define DAC_LOOPBACK_DISCONNECT       (0 << 0)

#define DAC_LOOPBACK_AMPLIFIER_ENABLE  (1 << 1)
#define DAC_LOOPBACK_AMPLIFIER_DISABLE (0 << 1)

#define DAC_LOOPBACK_ENABLE           (1 << 2)
#define DAC_LOOPBACK_DISABLE          (0 << 2)

/* OP_STAGE_CTRL register bit definitions */
#define DAC_VOLTAGE_MODE_DIS          (0 << 2) | (0 << 1) | (0 << 0)
/* DAC GAIN configuration is for Absolute mode*/
#define DAC_GAIN_10_V_V               (0 << 2) | (0 << 1) | (1 << 0)
#define DAC_GAIN_4_V_V                (0 << 2) | (1 << 1) | (0 << 0)
#define DAC_GAIN_2_V_V                (1 << 2) | (0 << 1) | (0 << 0)
#define DAC_GAIN_6_67_V_V             (1 << 2) | (1 << 1) | (0 << 0)
/* DAC GAIN configuration is for Ratiometric mode*/
#define DAC_GAIN_RATIOMETRIC_4_V_V    (0 << 2) | (1 << 1) | (0 << 0)

#define CL_4_20MA_ENABLE              (1 << 3)
#define CL_4_20MA_DISABLE             (0 << 3)

#define DACCAP_ENABLE                 (1 << 4)
#define DACCAP_DISABLE                (0 << 4)

#define PULLUP_ENABLE                 (1 << 5)
#define PULLUP_DISABLE                (0 << 5)

#define GATE_3P3_CTRL_VDD_14_V        (1 << 7)
#define GATE_3P3_CTRL_VDD_3_5_V       (0 << 7)

/* LVDT_OP_CTRL register bit definitions */
#define DACVCM_CTRL_0_82_V            (0 << 1) | (0 << 0)
#define DACVCM_CTRL_0_84_V            (0 << 1) | (1 << 0)
#define DACVCM_CTRL_0_86_V            (1 << 1) | (0 << 0)
#define DACVCM_CTRL_0_88_V            (1 << 1) | (1 << 0)

#define DIFF_VOCM_CTRL_0_75_V         (0 << 3) | (0 << 2)
#define DIFF_VOCM_CTRL_1_00_V         (0 << 3) | (1 << 2)
#define DIFF_VOCM_CTRL_1_25_V         (1 << 3) | (0 << 2)
#define DIFF_VOCM_CTRL_1_50_V         (1 << 3) | (1 << 2)

#define LVDT_GAIN_CTRL_1_00_V_V       (0 << 5) | (0 << 4)
#define LVDT_GAIN_CTRL_1_18_V_V       (0 << 5) | (1 << 4)
#define LVDT_GAIN_CTRL_1_40_V_V       (1 << 5) | (0 << 4)
#define LVDT_GAIN_CTRL_1_67_V_V       (1 << 5) | (1 << 4)

#define SKIP_FILTER_ENABLE            (1 << 6)
#define SKIP_FILTER_DISABLE           (0 << 6)

#define LVDT_SINGLE_ENDED_MODE        (0 << 7)
#define LVDT_SINGLE_DIFFERENTIAL_MODE (1 << 7)

/* LVDT_LPBK_CTRL - DAC loop-back control register definitions */
#define LVDT_LOOPBACK_CONNECT          (1 << 0)
#define LVDT_LOOPBACK_DISCONNECT       (0 << 0)
/* ========================================================================== */
/**
 * DAC_LOOPBACK_CONFIG() Configure DAC loop-back.
 *
 * @param x - Data to be written to loop-back control register.
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
#define DAC_LOOPBACK_CONFIG(x) (DAC_LPBK_CTRL = (x))

/* ========================================================================== */
/**
 * DAC_REG0_CONFIG() Configure DAC_REG0.
 *
 * @param x - 14 bit value.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define DAC_REG0_CONFIG(x) (DAC_REG0 = (x))
/* ========================================================================== */
/**
 * LVDT_OP_CTRL_CONFIG() Configure LVDT_OP_CTRL.
 *
 * @param x - 8 bit value.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define LVDT_OP_CTRL_CONFIG(x) (LVDT_OP_CTRL = (x))

/* ========================================================================== */
/**
 * LVDT_LPBK_CTRL_CONFIG() Configure LVDT_LPBK_CTRL.
 *
 * @param x - 8 bit value.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define LVDT_LPBK_CTRL_CONFIG(x) (LVDT_LPBK_CTRL = (x))

extern S2 DAC_Value; /* Value to be sent on DAC */

/* ========================================================================== */
/**
 * DAC_Reset_Init() Initializes all DAC related global variables.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void DAC_Reset_Init(void);

/* ========================================================================== */
/**
 * DAC_Config() Configure DAC.
 *
 * @param dacconfigValue Data to be written to DAC_CTRL_STATUS register.
 *
 * @param dacmodValue Data to be written to DAC_CONFIG register.
 *
 * @param dacgainValue Data to be written to OP_STAGE_CTRL register.
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
void DAC_Config(UC dacconfigValue, UC dacmodValue, UC dacgainValue);

/* ========================================================================== */
/**
 * DAC_Loopback_Config() Configure DAC loop-back.
 *
 * @param lpconfigValue Data to be written to loop-back control register.
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
void DAC_Loopback_Config(UC lpconfigValue);

#ifdef __cplusplus
}
#endif

#endif /* PGA970_DAC_H */
