/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_dev.h
*
* Header file for pga970_dev.c
*
* @path $(CSLPATH)\PGA970\source\chip\inc
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 08-Sept-2014 mf: Modified TusharB. Added PGA970 system related information.
* =========================================================================== */

#ifndef PGA970_DEV_H
#define PGA970_DEV_H

#ifdef __cplusplus
extern "C" {
#endif

/* Bit definition of CLK_CTRL */
#define CLK_CTRL             (0 << 1) | (1 << 0)
#define CLK_1MHZ             (0 << 1) | (0 << 0)
#define CLK_2MHZ             (0 << 1) | (1 << 0)
#define CLK_4MHZ             (1 << 1) | (0 << 0)
#define CLK_8MHZ             (1 << 1) | (1 << 0)

/* Bit definition of MICRO_INTERFACE_CONTROL register */
#define IF_SEL               (1 << 0)
#define MICRO_RESET          (1 << 1)
#define DEBUG_LOCK           (1 << 2)

#define MICRO_IF_SELECT      (0 << 0) /* M0 accesses PGA970 resources */
#define DIGITAL_IF_SELECT    (1 << 0) /* Digital IF accesses PGA970 resources */
#define MICRO_NORESET        (0 << 1)
#define DEBUG_UNLOCK         (0 << 2) /* Debug access PGA970 resource,IF_SEL=0*/

/* ========================================================================== */
/**
 * MICRO_INTERFACE_CONFIG() Configure Micro interface control register.
 *
 * @param x - value 0x00 to 0x07
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define MICRO_INTERFACE_CONFIG(x) (MICRO_INTERFACE_CONTROL = (x))

/* Bit definition of SECLOCK register */
#define SECURITY_LOCK_EN  (1 << 0) /* Enable when 0xAA is written to SECLOCK */
#define SECURITY_LOCK_DS  (0 << 0) /* Disable when 0x00 is written to SECLOCK */

/* ========================================================================== */
/**
 * SEC_LOCK_ENABLE() Enable security lock.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define SEC_LOCK_ENABLE() (SECLOCK = 0xAA)

/* ========================================================================== */
/**
 * SEC_LOCK_DISABLE() Disable security lock.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define SEC_LOCK_DISABLE() (SECLOCK = 0x00)

/* Bit definition of REMAP register */
#define REMAP_ENABLE          0x01
#define REMAP_DISABLE         0x00
/* ========================================================================== */
/**
 * M0_ConfigClock() Configure Cortex M0 clock.
 *
 * @param value Data to be written to clock control register
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void M0_ConfigClock(UC value);

/* ========================================================================== */
/**
 * REMAP_Config() Remaps the OTP memory to Development RAM area and vice versa.
 *
 * @param rvalue Data to be written to REMAP register.
 *               Valid value 0x00 or 0x03.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void REMAP_Config(UC rValue);

#ifdef __cplusplus
}
#endif

#endif /* PGA970_DEV_H */
