/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_diag.h
*
* Header file for pga970_diag.c
*
* @path $(CSLPATH)\PGA970\source\chip\inc
*
* @rev 1.2
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 06-June-2013 mf: Modified TusharB. Added / modified register bit definition.
*!
*! 25-Mar-2013 mf: Modified TusharB. Added diagnostic module related
*! information.
* =========================================================================== */

#ifndef PGA970_DIAG_H
#define PGA970_DIAG_H

#ifdef __cplusplus
extern "C" {
#endif

#if (DIAGNOSTIC_TESTING == 1)
/* Power Supply Diagnostics */
/* Bit definition of PSMON1 register */
#define REF_OV                  (1 << 2)
#define REF_UV                  (1 << 3)
#define AVDD_OV                 (1 << 4)
#define AVDD_UV                 (1 << 5)
#define LVDT_AVDD_OV            (1 << 6)
#define LVDT_AVDD_UV            (1 << 7)

/* Bit definition of PSMON2 register */
#define DVDD_OV                 (1 << 0)
#define OSC_BAD                 (1 << 4)
#define OSC_GOOD_CHECK_ENABLE   (1 << 6)
#define OSC_GOOD_CHECK_DISABLE  (0 << 6)

/* Bit definition of AFEDIAG register */
#define P1_OV                   (1 << 0)
#define P1_UV                   (1 << 1)
#define P1_OC                   (1 << 2)
#define P2_OV                   (1 << 3)
#define P2_UV                   (1 << 4)
#define P2_OC                   (1 << 5)
#define PE_OV                   (1 << 6)

/* Bit definition of AFEDIAG1 register */
#define S1_FAULT_OV             (1 << 0)
#define S1_GAIN_OV              (1 << 1)
#define S2_FAULT_OV             (1 << 4)
#define S2_GAIN_OV              (1 << 5)

/* Bit definition of AFEDIAG3 register */
#define VI_FAULT_OV             (1 << 4)
#define VI_GAIN_OV              (1 << 5)

/* Bit definition of AFEDIAG4 register */
#define PTAT_FAULT_OV           (1 << 0)
#define PTAT_GAIN_OV            (1 << 1)

/* Bit definition of AFEDIAG_CFG register */
#define S1_PULL_UP_ENABLE       (0 << 0)
#define S1_PULL_UP_DISABLE      (1 << 0)

#define S2_PULL_UP_ENABLE       (0 << 1)
#define S2_PULL_UP_DISABLE      (1 << 1)

#define S3_PULL_UP_ENABLE       (0 << 2)
#define S3_PULL_UP_DISABLE      (1 << 2)

#define PE_PULL_UP_ENABLE       (0 << 3)
#define PE_PULL_UP_DISABLE      (1 << 3)

/* ========================================================================== */
/**
 * GET_PSMON() Get the values of PSMON register.
 *             Please note all 10 bits (PSMON1+PSMON2 bits) are read.
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define GET_PSMON() (PSMON)

/* ========================================================================== */
/**
 * GET_AFEDIAG() Get the values of AFEDIAG register.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define GET_AFEDIAG() (AFEDIAG)

/* ========================================================================== */
/**
 * GET_AFEDIAG1() Get the values of AFEDIAG1 register.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define GET_AFEDIAG1() (AFEDIAG1)

/* ========================================================================== */
/**
 * GET_AFEDIAG3() Get the values of AFEDIAG3 register.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define GET_AFEDIAG3() (AFEDIAG3)

/* ========================================================================== */
/**
 * GET_AFEDIAG4() Get the values of AFEDIAG4 register.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define GET_AFEDIAG4() (AFEDIAG4)

/* ========================================================================== */
/**
 * AFEDIAG_CFG_CONFIG() Configure AFEDIAG_CFG register.
 *
 * @param x
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define AFEDIAG_CFG_CONFIG(x)      (AFEDIAG_CFG = (x))
#endif

#ifdef __cplusplus
}
#endif

#endif /* PGA970_DIAG_H */
