/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_dif.h
*
* Header file for pga970_dif.c
*
* @path $(CSLPATH)\PGA970\source\chip\inc
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 08-Sept-2014 mf: Modified TusharB. Added Digital interface bit definitions.
* =========================================================================== */

#ifndef PGA970_DIF_H
#define PGA970_DIF_H

#ifdef __cplusplus
extern "C" {
#endif

/* Bit definition of DIG_IF_CTRL register */
#define SPI_ENABLE               (1 << 0)
#define OWI_ENABLE               (1 << 2)
#define OWI_TRANSCEIVER_ENABLE   (1 << 3)
#define OWI_DEGLITCH_FILTER_10MS (1 << 4)

#define SPI_DISABLE              (0 << 0)
#define OWI_DISABLE              (0 << 2)
#define OWI_XCVR_DISABLE         (0 << 3)
#define OWI_DEGLITCH_FILTER_1MS  (0 << 4)

/* ========================================================================== */
/**
 * FRAM_PAGE_ADDR_CONFIG() Configure page address for read/write accesses to
 *                         FRAM from Digital interface.
 *
 * @param x Valid range 0x00 to 0x1F
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define FRAM_PAGE_ADDR_CONFIG(x)    (FRAM_PAGE_ADDR = (x))

/* ========================================================================== */
/**
 * DATARAM_PAGE_ADDR_CONFIG() Configure page address for read/write accesses to
 *                          Data SRAM from Digital interface.
 *
 * @param x Valid range 0x00 to 0x03
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define DATA_WAVE_PAGE_ADDR_CONFIG(x)  (DATA_WAVE_PAGE_ADDR = (x))

/* ========================================================================== */
/**
 * DEVRAM_PAGE_ADDR_CONFIG() Configure page address for read/write accesses to
 *                           Development RAM from Digital interface.
 *
 * @param x Valid range 0x00 to 0x1F
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define DEVRAM_PAGE_ADDR_CONFIG(x) (DEVRAM_PAGE_ADDR = (x))

/* ========================================================================== */
/**
 * DIGITAL_Interface_Config() Configure digital interface for communication.
 *
 * @param diconfigValue Data to be written to digital interface config register
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void DIGITAL_Interface_Config(UC diconfigValue);

#ifdef __cplusplus
}
#endif

#endif /* PGA970_DIF_H */
