/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_fram.h
*
* Header file for pga970_fram.c
*
* @path $(CSLPATH)\PGA970\source\chip\inc
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 23-Apr-2015 mf: Modified AbhimanyuK. Added FRAM module related definitions.
* =========================================================================== */
#include "pga970_platf.h"

#ifndef PGA970_FRAM_H
#define PGA970_FRAM_H

#ifdef __cplusplus
extern "C" {
#endif

extern VS2 FRAM_DATA_H0_Integer;
extern VS2 FRAM_DATA_G0_Integer;
extern VS2 FRAM_DATA_N0_Integer;

extern VS2 FRAM_DATA_H1_Integer;
extern VS2 FRAM_DATA_G1_Integer;
extern VS2 FRAM_DATA_N1_Integer;

extern VS2 FRAM_DATA_H2_Integer;
extern VS2 FRAM_DATA_G2_Integer;
extern VS2 FRAM_DATA_N2_Integer;



/* ========================================================================== */
/**
 * FRAM_DATA_Read_Coeff() Read coefficients from FRAM DATA area.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void FRAM_DATA_Read_Coeff(void);


#if (FRAM_DATA_TESTING == 1)
/* ========================================================================== */
/**
 * FRAM_DATA_Read() Read values from FRAM DATA.
 *
 * @param numBytes Number of bytes to be read.
 *
 * @param framdataOffset Offset of FRAM DATA valid range 0 to 2048.
 *
 * @param destPtr Pointing to the address where read data to be stored.
 *
 * @return 1 if success and 0 if unsuccessful.
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
UC FRAM_DATA_Read(US numBytes, US framdataOffset, void *destPtr);

/* ========================================================================== */
/**
 * FRAM_DATA_Write() Writes to FRAM DATA.
 *
 * @param numBytes Number of bytes to be read.
 *
 * @param framdataOffset Offset of FRAM DATA valid range 0 to 2048.
 *
 * @param srcPtr Pointing to the address from where data to be stored.
 *
 * @return 1 on successful write, else 0.
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
UC FRAM_DATA_Write(US numBytes, US framdataOffset, void *srcPtr);
#endif /*#if (FRAM_DATA_TESTING == 1)*/

#if (FRAM_TEXT_CHECKSUM_CALC==1)
/* ========================================================================== */
/**
 * FRAM_TEXT_Checksum() Computes FRAM TEXT area Checksum.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void FRAM_TEXT_Checksum(void);
#endif /*#if (FRAM_TEXT_CHECKSUM_CALC==1)*/

#if (FRAM_DATA_CHECKSUM_CALC==1)
/* ========================================================================== */
/**
 * FRAM_DATA_Checksum() Computes FRAM DATA area Checksum.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void FRAM_DATA_Checksum(void);
#endif /*#if (FRAM_DATA_CHECKSUM_CALC==1)*/


#ifdef __cplusplus
}
#endif

#endif /* PGA970_FRAM_H */
