/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_gpio.h
*
* Header file for pga970_gpio.c
*
* @path $(CSLPATH)\PGA970\source\chip\inc
*
* @rev 1.0
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 29-Apr-2015 mf: Modified AbhimanyuK. Added GPIO module related information.
* =========================================================================== */

#ifndef PGA970_GPIO_H
#define PGA970_GPIO_H

#ifdef __cplusplus
extern "C" {
#endif

#if (GPIO_TESTING==1)
/* Bit definition of GPIO_OUTPUT */
#define GPIO1_OUTPUT            (1 << 0)
#define GPIO2_OUTPUT            (1 << 1)

/* Bit definition of GPIO_INPUT NJH*/
#define BIT_0                   0x01
#define BIT_1                   0x02

/* Bit definition of GPIO_DIR register */
#define	GPIO1_DIR_INPUT         (1 << 0)
#define	GPIO2_DIR_INPUT         (1 << 1)

#define	GPIO1_DIR_OUTPUT        (0 << 0)
#define	GPIO2_DIR_OUTPUT        (0 << 1)

/* Bit definition of GPIO_OPTYPE register */
#define	GPIO1_PUSH_PULL         (0 << 0)
#define	GPIO1_OPEN_DRAIN        (1 << 0)
#define	GPIO2_PUSH_PULL         (0 << 1)
#define	GPIO2_OPEN_DRAIN        (1 << 1)
#endif /*#if (GPIO_TESTING==1)*/

/*Bit definition of PIN_MUX*/

#define TOPDIG_GPIO_2_PIN_ENABLE      (1 << 1)
#define GPIO_OP_GPIO_2_PIN_ENABLE     (0 << 1)

#define PWM34_OP_ON_PWM4_PIN          (1 << 4)
#define PWM34_OP_ON_PWM3_PIN          (0 << 4)

#if (GPIO_TESTING==1)
/* ========================================================================== */
/**
 * GPIO1_HIGH() GPIO1 output is high.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define GPIO1_HIGH() (GPIO_OUTPUT |= GPIO1_OUTPUT) /* GPIO1 o/p is high */

/* ========================================================================== */
/**
 * GPIO1_LOW() GPIO1 output is low.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define GPIO1_LOW()  (GPIO_OUTPUT &= ~GPIO1_OUTPUT)/* GPIO1 o/p is low  */

/* ========================================================================== */
/**
 * GPIO2_HIGH() GPIO2 output is high.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define GPIO2_HIGH() (GPIO_OUTPUT |= GPIO2_OUTPUT) /* GPIO2 o/p is high */

/* ========================================================================== */
/**
 * GPIO2_LOW() GPIO2 output is low.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define GPIO2_LOW()  (GPIO_OUTPUT &= ~GPIO2_OUTPUT)/* GPIO2 o/p is low  */
/* ========================================================================== */
/**
 * GPIO1_TOGGLE() GPIO1 output is toggled.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define GPIO1_TOGGLE()  (GPIO_OUTPUT ^= GPIO1_OUTPUT)/* GPIO1 o/p is toggled */

/* ========================================================================== */
/**
 * GET_GPIO1() Get GPIO1 input value.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define GET_GPIO1()  ((GPIO_INPUT & BIT_0) ? 1 : 0) /* GPIO1 input value */
/* same as:
 *  if (GPIO_INPUT & BIT_0)
 *      return 1;           // return 1 if true
 *  else
 *      return 0;           // return 0 if false
 */
/* ========================================================================== */
/**
 * GPIO2_TOGGLE() GPIO2 output is toggled.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define GPIO2_TOGGLE()  (GPIO_OUTPUT ^= GPIO2_OUTPUT)/* GPIO2 o/p is toggled */

/* ========================================================================== */
/**
 * GET_GPIO2() Get GPIO2 input value.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define GET_GPIO2()  ((GPIO_INPUT & BIT_1) ? 1 : 0) /* GPIO2 input value */

/* ========================================================================== */
/**
 * GPIO_Config() Configure GPIO.
 *
 * @param gpioDir GPIO direction input or output
 *
 * @param gpioOuttype GPIO output type -> open drain or pushpull
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
void GPIO_Config(UC gpioDir, UC gpioOuttype);

/* ========================================================================== */

 UC Get_GPIO_Dir();
 UC Get_GPIO_Outtype();

#endif /*#if (GPIO_TESTING==1)*/
/* ========================================================================== */
/**
 * PIN_MUX_Config() Configure PIN_MUX.
 *
 * @param pinMuxConfig configures TOPDIG output pin
 *
 * @param none
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
void PIN_MUX_Config(UC pinMuxConfig);

#ifdef __cplusplus
}
#endif

#endif /* PGA970_GPIO_H */
