/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_mux.h
*
* Header file for analog & digital multiplexer selection.
*
* @path $(CSLPATH)\PGA970\source\chip\inc
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 01-July-2013 mf: Modified TusharB. Added digital & analog multiplexer select
*! signals.
* =========================================================================== */

#ifndef PGA970_MUX_H
#define PGA970_MUX_H

#ifdef __cplusplus
extern "C" {
#endif

/*Bit definitions for  AMUX_ACT register */
#define TIN_MUX_ENABLE              (1 << 0)
#define TOUT_MUX_ENABLE             (1 << 1)
#define TIN_MUX_DISABLE             (0 << 0)
#define TOUT_MUX_DISABLE            (0 << 1)

/*Bit definitions for  AMUX_CTRL register */
#define DAC_OP_TO_DAC_GAIN          (1 << 0)
#define DAC_OP_TO_TOP_TON           (0 << 0)
#define S1_OP_TO_ADC1               (1 << 1)
#define S1_OP_TO_TOP_TON            (0 << 1)
#define S2_OP_TO_ADC2               (1 << 2)
#define S2_OP_TO_TOP_TON            (0 << 2)
#define S3_OP_TO_ADC3               (1 << 3)
#define S3_OP_TO_TOP_TON            (0 << 3)
#define WAVEFORM_DAC_OP_TO_WAVEFORM_GAIN ((1 << 4)|(1 << 5)|(1 << 6)|(1 << 7))
#define WAVEFORM_DAC_OP_TO_TOP_TON  ((0 << 4)|(0 << 5)|(0 << 6)| (0 << 7))
/*
 * Analog multiplexer signal selection for TIP and TIN signal
 * AMUX_TIN_MUX_CTRL
 */
#define TIP_DAC_BUF_RATIOMETRIC_OUTPUT 0x00
#define TIP_ADC_OTA_COMMON_MODE_BUFFER 0x01
#define TIP_OUTPUT_BUFFER              0x02
#define TIP_TEST_MUX_OSCILLATOR        0x03
#define TIP_LOOP_BACK_AMPLIFIER        0x04
#define TIP_PRESSURE_ADC_INPUT_1       0x05
#define TIP_BRIDGE_BUFFER              0x06
#define TIP_T_ADC_INPUT_1              0x07

#define TIN_EXTERNAL_TEST_CLOCK        0x00
#define TIN_ACD_REF_COMMON_MODE_BUFFER 0x01
#define TIN_PRESSURE_ADC_INPUT_2       0x05
#define TIN_ADC_REF_BUFFER             0x06
#define TIN_T_ADC_INPUT_2              0x07

/*
 * Analog multiplexer signal selection for TOP signal
 * AMUX_TOUT_MUX_CTRL
 */
#define TOP_BRIDGE_VOLTAGE             0x00
#define TOP_TPGA_OUTPUT_1              0x01
#define TOP_SPARE                      0x02
#define TOP_HIGH_VOLTAGE_REF           0x03
#define TOP_DAC_BUF_RATIOMETRIC_OUTPUT 0x04
#define TOP_DAC_OUTPUT                 0x05
#define TOP_REF_CURRENT_TRIM_V_I       0x06
#define TOP_AVSS                       0x07
#define TOP_ADC_OTA_COM_MODE           0x08
#define TOP_LOOP_BACK_OUTPUT_P         0x09
#define TOP_PPGA_OUTPUT_1              0x0A
#define TOP_AVDD                       0x0C
#define TOP_TIP                        0x0D
#define TOP_P_PGA_VCM                  0x0E

#define TON_ADC_REF                    0x00
#define TON_TPGA_OUTPUT_2              0x01
#define TON_OSCILLATOR                 0x02
#define TON_AVSS                       0x03
#define TON_2_5V_REF                   0x04
#define TON_REF_GROUND                 0x05
#define TON_ACD_REF_COM_MODE           0x08
#define TON_LOOP_BACK_OUTPUT_N         0x09
#define TON_PPGA_OUTPUT_2              0x0A
#define TON_OSCILLATOR_VDD             0x0C
#define TON_TIN                        0x0D
#define TON_T_PGA_VCM                  0x0E

/* Digital multiplexer selection
 * TOPDIAG_MUX_SEL or TONDIAG_MUX_SEL*/
#define DIG_MUX_SEL_REF_OV                 0x02
#define DIG_MUX_SEL_AVDD_OV                0x03
#define DIG_MUX_SEL_LVDT_VDD_OV            0x04
#define DIG_MUX_SEL_DVDD_OV                0x05
#define DIG_MUX_SEL_OSC_REF_OV             0x06
#define DIG_MUX_SEL_REF_UV                 0x08
#define DIG_MUX_SEL_AVDD_UV                0x09
#define DIG_MUX_SEL_LVDT_VDD_UV            0x0A
#define DIG_MUX_SEL_DVDD_UV                0x0B
#define DIG_MUX_SEL_OSC_REF_UV             0x0C
#define DIG_MUX_SEL_P1_OV                  0x0D
#define DIG_MUX_SEL_P1_UV                  0x0E
#define DIG_MUX_SEL_P1_OC                  0x0F
#define DIG_MUX_SEL_P2_OV                  0x10
#define DIG_MUX_SEL_P2_UV                  0x11
#define DIG_MUX_SEL_P2_OC                  0x12
#define DIG_MUX_SEL_PE_OV                  0x13
#define DIG_MUX_SEL_S1_FAULT_OV            0x14
#define DIG_MUX_SEL_S1_GAIN_OV             0x15
#define DIG_MUX_SEL_S2_FAULT_OV            0x17
#define DIG_MUX_SEL_S2_GAIN_OV             0x18
#define DIG_MUX_SEL_S3_FAULT_OV            0x1A
#define DIG_MUX_SEL_S3_GAIN_OV             0x1B
#define DIG_MUX_SEL_OWI_ERROR_STATUS_LO_0  0x1D
#define DIG_MUX_SEL_OWI_ERROR_STATUS_LO_1  0x1E
#define DIG_MUX_SEL_OWI_ERROR_STATUS_LO_2  0x1F
#define DIG_MUX_SEL_OWI_ERROR_STATUS_LO_3  0x20
#define DIG_MUX_SEL_OWI_ERROR_STATUS_LO_4  0x21
#define DIG_MUX_SEL_OWI_ERROR_STATUS_LO_5  0x22
#define DIG_MUX_SEL_OWI_ERROR_STATUS_LO_6  0x23
#define DIG_MUX_SEL_OWI_ERROR_STATUS_LO_7  0x24
#define DIG_MUX_SEL_OWI_ERROR_STATUS_HI_0  0x25
#define DIG_MUX_SEL_OWI_ERROR_STATUS_HI_1  0x26
#define DIG_MUX_SEL_OWI_RECEIVE_DATA       0x27
#define DIG_MUX_SEL_OWI_TRANSMIT_DATA      0x2A
#define DIG_MUX_SEL_ADC1_INTERRUPT         0x2D
#define DIG_MUX_SEL_OWI_ACT_INTERRUPT      0x2F
#define DIG_MUX_SEL_OWI_COMBUF_INTERRUPT   0x30
#define DIG_MUX_SEL_OSC_8MHZ               0x3D
#define DIG_MUX_SEL_M0_CLK                 0x3E
#define DIG_MUX_SEL_S1_S2_ADC_CLK          0x3F
#define DIG_MUX_SEL_ADC3_CLK               0x40
#define DIG_MUX_SEL_DEMOD1_DECI_CLK        0x44
#define DIG_MUX_SEL_DEMOD2_DECI_CLK        0x45
#define DIG_MUX_SEL_ADC3_DECI_CLK          0x46
#define DIG_MUX_SEL_WSRAM_MBIST_DONE       0x4A
#define DIG_MUX_SEL_WSRAM_MBIST_FAIL       0x4B
#define DIG_MUX_SEL_RAM_MBIST_DONE         0x4D
#define DIG_MUX_SEL_RAM_MBIST_FAIL         0x4E
#define DIG_MUX_SEL_ADC_CONVERSION_START   0x59

/* ========================================================================== */
/**
 * TOPDIG_MUX_CONFIG() Configure the signals driven to the TOPDIG test output.
 *
 * @param x - Value ranging from 0x00 to 0x3F
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define TOPDIG_MUX_CONFIG(x) (TOPDIG_MUX_SEL = (x))

/* ========================================================================== */
/**
 * AMUX_ACT_CONFIG() Enable/disable analog input &/or output test multiplexer.
 *
 * @param x - value 0x00 to 0x02
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define AMUX_ACT_CONFIG(x)          (AMUX_ACT = (x))

/* ========================================================================== */
/**
 * AMUX_TIN_MUX_CONFIG() Multiplexer select for analog test multiplexer input.
 *
 * @param x
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define AMUX_TIN_MUX_CONFIG(x)      (AMUX_TIN_MUX_CTRL = (x))

/* ========================================================================== */
/**
 * AMUX_TOUT_MUX_CONFIG() Multiplexer select for analog test multiplexer output.
 *
 * @param x
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define AMUX_TOUT_MUX_CONFIG(x)     (AMUX_TOUT_MUX_CTRL = (x))

/* ========================================================================== */
/**
 * AMUX_CTRL_CONFIG() Analog multiplexer control.
 *
 * @param x - value 0x00 to 0x0F.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define AMUX_CTRL_CONFIG(x)              (AMUX_CTRL = (x))

#ifdef __cplusplus
}
#endif

#endif /* PGA970_MUX_H */
