/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_owi.h
*
* Header file for pga970_owi.c
*
* @path $(CSLPATH)\PGA970\source\chip\inc
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 08-Sept-2014 mf: Modified TusharB. Added OWI module related information.
* =========================================================================== */

#ifndef PGA970_OWI_H
#define PGA970_OWI_H

#ifdef __cplusplus
extern "C" {
#endif

#if (OWI_TESTING==1)
/* Bit definition of OWI_ERROR_STATUS_LO register */
#define SYNC_FIELD_BIT_RATE_LT_320BPS      (1 << 0)
#define SYNC_FIELD_BIT_RATE_GT_19200BPS    (1 << 1)
#define SYNC_FIELD_STOP_BIT_SHORT          (1 << 2)
#define CMD_FIELD_INCORRECT_STOP_BIT       (1 << 3)
#define CMD_FIELD_STOP_BIT_SHORT           (1 << 4)
#define DATA_FIELD_INCORRECT_STOP_BIT      (1 << 5)
#define DATA_FIELD_STOP_BIT_SHORT          (1 << 6)
#define DATA_FIELD_SLAVE_TX_OVERDRIVEN     (1 << 7)

/* Bit definition of OWI_ERROR_STATUS_HI register */
#define SYNC_FIELD_BITS_DIFFERENT          (1 << 0)
#define INVALID_CMD_SENT                   (1 << 1)
#define CLEAR_OWI_ERROR_STATUS             (1 << 7)

/* Bit definition of OWI_INTERRUPT register */
#define OWI_INTERRUPT_ACTIVE               (1 << 0)

/* Bit definition of OWI_INTERRUPT_ENABLE register */
#define OWI_INT_ENABLE                     (1 << 0)
#define OWI_INT_DISABLE                    (0 << 0)

/* Bit definition of DLPWR register */
#define OWI_CLK_EN                         (1 << 0)

/* ========================================================================== */
/**
 * OWI_CLOCK_ENABLE() Enables OWI clock.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define OWI_CLOCK_ENABLE() (DLPWR = OWI_CLK_EN)

/* ========================================================================== */
/**
 * OWI_TRANSCEIVER_DISABLE() Disable OWI transceiver.
 *                           OWI Transceiver is disconnected from VDD
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define OWI_TRANSCEIVER_DISABLE() (DIG_IF_CTRL &= ~OWI_TRANSCEIVER_ENABLE)

/* ========================================================================== */
/**
 * OWI_Activation_Handler() Interrupt subroutine for OWI activation.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void OWI_Activation_Handler(void);

/* ========================================================================== */
/**
 * OWI_Config() Configure OWI interface interrupt registers & Enable OWI clock.
 *
 * @param owiInt Data to be written to OWI_INTERRUPT_ENABLE register.
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
void OWI_Config(UC owiInt);
#endif /*#if (OWI_TESTING==1)*/
#ifdef __cplusplus
}
#endif

#endif /* PGA970_OWI_H */
