/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_syst.h
*
* Header file for pga970_syst.c
*
* @path $(CSLPATH)\PGA970\source\chip\inc
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 08-Sept-2014 mf: Modified TusharB. System tick timer module.
* =========================================================================== */

#ifndef PGA970_SYST_H
#define PGA970_SYST_H

#ifdef __cplusplus
extern "C" {
#endif

#if (SYST_TESTING == 1)
/*
 * Calculate timer reload value for 1ms timeout
 * 1ms system tick @1MHz CPU clock
 * NVIC_ST_RELOAD = 1msec * CPU clock
 *                = 1msec * 1MHz
 *                = 1msec * 1usec
 *                = 1000 = 0x3E8
 */
#define SYSTICK_RELOAD_CNT 1000

/* ========================================================================== */
/**
 * SYST_GET_CVR() Get SysTick current value.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
#define SYST_GET_CVR() (SYST_CVR)

/* ========================================================================== */
/**
 * SYST_Config() Configure Cortex M0 system timer.
 *
 * @param reloadCnt Data to be written to SYST_RVR systick reload register.
 *
 * @param systControl Data to be written to SYST_CSR systick control register.
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void SYST_Config(UL reloadCnt, UL systControl);

/* ========================================================================== */
/**
 * SYST_Handler() Interrupt subroutine for Cortex M0 system timer.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void SYST_Handler(void);
#endif /* SYST_TESTING */

#ifdef __cplusplus
}
#endif

#endif /* PGA970_SYST_H */
