/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_waveform.h
*
* Header file for pga970_waveform.c
*
* @path $(CSLPATH)\PGA970\source\chip\inc
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 23-Apr-2015 mf: Modified AbhimanyuK. Added waveform module related definitions.
* =========================================================================== */
#ifndef PGA970_WAVEFORM_H
#define PGA970_WAVEFORM_H

#ifdef __cplusplus
extern "C" {
#endif


#if (WAVEFORM_TESTING == 1)
#define WAVEFORM_TABLE_OFFSET         0x600
#define WAVEFORM_TABLE_SIZE_OFFSET    0x12


#define WAVEFORM_TABLE_SIZE    256
/* Bit definition of WAVEFORM_GEN_CTRL register */
#define WAVEFORM_GEN_ENABLE         (1 << 0)
#define WAVEFORM_GEN_DISABLE        (0 << 0)

/*For 0.86v bias, WAVEFORM_DAC_OFFSET value is(0.86(DAC Resolution/DAC Range)
 * i.e. (0.86(16383/1.25) = 0x2C08 approx
 * */
#define WAVEFORM_DAC_OFFSET_VAL   0x2C08

/*Table size is read from FRAM_DATA area if supported else default value*/
extern UC Waveform_Table_size;
/* ========================================================================== */
/**
 * WAVEFORM_Read_Table() Read coefficients from FRAM DATA.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void WAVEFORM_Read_Table(void);

/* ========================================================================== */
/**
 * WAVEFORM_Config() Configure waveform registers.
 *
 * @param tableLength waveform table length WAVEFORM_TABLE_LEN register.
 *
 * @param dacoffset Data to be written to WAVEFORM_DAC_OFFSET register.
 *
 * @param genCtrl Data to be written to WAVEFORM_GEN_CTRL register.
 *
 * @return none
 *
 * @post none
 */
/* ========================================================================== */
void WAVEFORM_Config(UC tableLength, US dacoffset, UC genCtrl);

#endif /*#if (WAVEFORM_TESTING == 1)*/

#ifdef __cplusplus
}
#endif

#endif /* PGA970_WAVEFORM_H */
