/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_wdt.h
*
* Header file for pga970 watch dog timer.
*
* @path $(CSLPATH)\PGA970\source\chip\inc
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 01-July-2013 mf: Modified TusharB. Added watch-dog timer  module related
*! information.
* =========================================================================== */

#ifndef PGA970_WDT_H
#define PGA970_WDT_H

#ifdef __cplusplus
extern "C" {
#endif

#if (WATCH_DOG_TIMER_TESTING == 1)
/* Bit definition of WDOG_CTRL_STAT */
#define WATCH_DOG_TIMER_ENABLE  (1 << 0)
#define WATCH_DOG_RESET_STS     (1 << 6)
#define WATCH_DOG_TIMER_RESET   (1 << 7)

#define WDT_ENABLE()            (WDOG_CTRL_STAT |= WATCH_DOG_TIMER_ENABLE)
#define WDT_DISABLE()           (WDOG_CTRL_STAT &= ~(WATCH_DOG_TIMER_ENABLE))
#define WDT_RESET_CLEAR()       (WDOG_CTRL_STAT |= WATCH_DOG_TIMER_RESET)
#define WDT_TIMED_OUT()         ((WDOG_CTRL_STAT & WATCH_DOG_TIMER_RESET) ? 1 : 0)

/*
 * The watch-dog timeout value = (register_value+1)*2 ms
 * Maximum register_value is 0xFF so watch dog timer timeout will be
 *  (0xFF+1)*2ms = 512ms
 */
#define WDT_TRIGGER(x)          (WDOG_TRIG_HIGH = (x))
/*
 * The watch-dog low timeout value = (register_value)*2 ms
 * Maximum register_value is 0xFF so watch dog timer timeout
 *  will be (0xFF)*2ms = 510ms
 */
#define WDT_TRIG_LOW_CONFIG(x)  (WDOG_TRIG_LOW = (x))
#endif

#ifdef __cplusplus
}
#endif

#endif /* PGA970_WDT_H */
