/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_combuf.c
*
* This File contains code used for PGA970 COMBUF related activities.
*
* @path $(CSLPATH)\PGA970\source\chip
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 27-Apr-2015 mf: Modified AbhimanyuK. Added COMBUF module related functions.
* =========================================================================== */

/*******************************************************************************
* INCLUDE FILES
*******************************************************************************/
#include "pga970_platf.h"

#if (COMBUF_TESTING == 1)
VUC COMBUF_Flag;                        /* COMBUF ISR flag */
VUS COMBUF_Rx_Buf[1];                   /* COMBUF received value*/

/* ========================================================================== */
/**
 * @fn COMBUF_Reset_Init() Initializes all COMBUF related global variables.
 *
 * @see pga970_combuf.h
 */
/* ========================================================================== */
void COMBUF_Reset_Init(void)
{
   COMBUF_Flag = 0;
   COMBUF_Rx_Buf[0] = 0;
}



/* ========================================================================== */
/**
 * @fn COMBUF_Handler() Interrupt subroutine for COMBUF.
 *
 * @see pga970_combuf.h
 */
/* ========================================================================== */
interrupt void COMBUF_Handler(void)
{
   COMBUF_Rx_Buf[0] = COM_DIF_TO_MCU_B; /* Read combuf data */
   COMBUF_RX_STATUS_CLEAR();            /* Clear receive status */
   COMBUF_Flag = 1;                     /* Flag to process rx data */
}
#endif /*#if (COMBUF_TESTING == 1)*/
