/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_dac.c
*
* This File contains code used for PGA970 DAC related activities.
*
* @path $(CSLPATH)\PGA970\source\chip
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 01-July-2013 mf: Modified TusharB. Added DAC module related functions.
* =========================================================================== */

/*******************************************************************************
* INCLUDE FILES
*******************************************************************************/
#include "pga970_platf.h"

S2 DAC_Value; /* Value to be sent on DAC */

/* ========================================================================== */
/**
 * @fn DAC_Reset_Init() Initializes all DAC related global variables.
 *
 * @see pga970_dac.h
 */
/* ========================================================================== */
void DAC_Reset_Init(void)
{
   DAC_Value = 0x00;
}

/* ========================================================================== */
/**
 * @fn DAC_Config() Configure DAC.
 *
 * @see pga970_dac.h
 */
/* ========================================================================== */
void DAC_Config(UC dacconfigValue, UC dacmodValue, UC dacgainValue)
{
   OP_STAGE_CTRL = dacgainValue;
   DAC_CONFIG = dacmodValue;
   DAC_CTRL_STATUS = dacconfigValue;
   /*Connect DAC output to DAC gain*/
   AMUX_CTRL = ((AMUX_CTRL & ~0x01) | (DAC_OP_TO_DAC_GAIN & 0x01));
}
/* ========================================================================== */
/**
 * @fn DAC_Loopback_Config() Configure DAC loop-back.
 *
 * @see pga970_dac.h
 */
/* ========================================================================== */
void DAC_Loopback_Config(UC lpconfigValue)
{
   DAC_LPBK_CTRL = lpconfigValue;
}
