/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_owi.c
*
* This File contains code used for PGA970 OWI related activities.
*
* @path $(CSLPATH)\PGA970\source\chip
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 01-July-2013 mf: Modified TusharB. Added OWI module related functions.
* =========================================================================== */

/*******************************************************************************
* INCLUDE FILES
*******************************************************************************/
#include "pga970_platf.h"

#if (OWI_TESTING == 1)
/* ========================================================================== */
/**
 * @fn OWI_Interrupt_Config() Configure OWI interrupt.
 *
 * @see pga970_owi.h
 */
/* ========================================================================== */
void OWI_Config(UC owiInt)
{
   /* Enable clock to the OWI controller */
   OWI_CLOCK_ENABLE();
   /* Enable OWI Interrupt */
   /* Disable OWI Transceiver */
   OWI_TRANSCEIVER_DISABLE();
   /* Clear OWI interrupt */
   OWI_INTERRUPT = 0x01; /* Write of '1', clears the interrupt status */
   /* Enable OWI Interrupt */
   OWI_INTERRUPT_ENABLE = owiInt;
}

/* ========================================================================== */
/**
 * @fn OWI_Activation_Handler() Interrupt subroutine for OWI activation.
 *
 * @see pga970_owi.h
 */
/* ========================================================================== */
interrupt void OWI_Activation_Handler(void)
{
   /* Clear OWI interrupt */
   OWI_INTERRUPT = 0x01; /* Write of '1', clears the interrupt status */
   /* Enable OWI Transceiver */
   DIG_IF_CTRL |= OWI_TRANSCEIVER_ENABLE;
}
#endif
