/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_syst.c
*
* This File contains code used for PGA970 Timer's related activities.
*
* @path $(CSLPATH)\PGA970\source\chip
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 01-July-2013 mf:Modified TusharB. System tick timer module.
* =========================================================================== */

/*******************************************************************************
* INCLUDE FILES
*******************************************************************************/
#include "pga970_platf.h"

#if (SYST_TESTING == 1)
/* ========================================================================== */
/**
 * @fn SYST_Config() Configure Cortex M0 system timer.
 *
 * @see pga970_syst.h
 */
/* ========================================================================== */
void SYST_Config(UL reloadCnt, UL systControl)
{
   /* Program reload value */
   SYST_RVR = reloadCnt;
   /* Clear current value */
   SYST_CVR = 0x0;
   /* Program status & control register */
   SYST_CSR = systControl;
}

/* ========================================================================== */
/**
 * @fn SYST_Handler() Interrupt subroutine for Cortex M0 system timer.
 *
 * @see pga970_syst.h
 */
/* ========================================================================== */
interrupt void SYST_Handler(void)
{
   /* Disable System tick  counter */
   SYST_CSR &= ~ST_ENABLE;

   /* Add code here */

   /* Enable System tick  counter */
   SYST_CSR |= ST_ENABLE;
}
#endif /* SYST_TESTING */
