/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_waveform.c
*
* This File contains code used for PGA970 Waveform related activities.
*
* @path $(CSLPATH)\PGA970\source\chip
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 28-Apr-2015 mf: Modified AbhimanyuK.Updated waveform related functions.
* =========================================================================== */

/*******************************************************************************
* INCLUDE FILES
*******************************************************************************/
#include "pga970_platf.h"

#if(WAVEFORM_TESTING==1)
#pragma DATA_SECTION(waveformTable, ".waveform_table");
US waveformTable[WAVEFORM_TABLE_SIZE];

UC Waveform_Table_size;
/* ========================================================================== */
/**
 * @fn WAVEFORM_Read_Table() Read Waveform Table from FRAM DATA location
 * reserved for Waveform table.
 *
 * @see pga970_waveform.h
 */
/* ========================================================================== */
void WAVEFORM_Read_Table(void)
{
#if (FRAM_DATA_TESTING == 1)
   /*Read waveform table size*/
   FRAM_DATA_Read(1,WAVEFORM_TABLE_SIZE_OFFSET,&Waveform_Table_size);

   memcpy((void *)waveformTable,
          (void *)(FRAM_DATA_START_ADDRESS + WAVEFORM_TABLE_OFFSET),
          Waveform_Table_size);
#else
   /*5KHz. For 5KHz, 50 samples are needed. Program 50-1=49 in the register*/
    Waveform_Table_size = 0x31;
    waveformTable[0] = 0x43;
    waveformTable[1] = 0xC9;
    waveformTable[2] = 0x14E;
    waveformTable[3] = 0x1D3;
    waveformTable[4] = 0x258;
    waveformTable[5] = 0x2DC;
    waveformTable[6] = 0x360;
    waveformTable[7] = 0x3E2;
    waveformTable[8] = 0x464;
    waveformTable[9] = 0x4E5;
    waveformTable[10] = 0x564;
    waveformTable[11] = 0x5E2;
    waveformTable[12] = 0x65E;
    waveformTable[13] = 0x6D9;
    waveformTable[14] = 0x752;
    waveformTable[15] = 0x7C9;
    waveformTable[16] = 0x83F;
    waveformTable[17] = 0x8B2;
    waveformTable[18] = 0x923;
    waveformTable[19] = 0x991;
    waveformTable[20] = 0x9FE;
    waveformTable[21] = 0xA67;
    waveformTable[22] = 0xACF;
    waveformTable[23] = 0xB33;
    waveformTable[24] = 0xB94;
    waveformTable[25] = 0xBF3;
    waveformTable[26] = 0xC4F;
    waveformTable[27] = 0xCA7;
    waveformTable[28] = 0xCFD;
    waveformTable[29] = 0xD4F;
    waveformTable[30] = 0xD9D;
    waveformTable[31] = 0xDE8;
    waveformTable[32] = 0xE30;
    waveformTable[33] = 0xE74;
    waveformTable[34] = 0xEB5;
    waveformTable[35] = 0xEF1;
    waveformTable[36] = 0xF2A;
    waveformTable[37] = 0xF60;
    waveformTable[38] = 0xF91;
    waveformTable[39] = 0xFBE;
    waveformTable[40] = 0xFE8;
    waveformTable[41] = 0x100D;
    waveformTable[42] = 0x102E;
    waveformTable[43] = 0x104B;
    waveformTable[44] = 0x1064;
    waveformTable[45] = 0x1079;
    waveformTable[46] = 0x108A;
    waveformTable[47] = 0x1097;
    waveformTable[48] = 0x109F;
    waveformTable[49] = 0x10A3;
#endif /*#if (FRAM_DATA_TESTING == 1)*/
}

/* ========================================================================== */
/**
 * @fn WAVEFORM_Config() Configure waveform registers.
 *
 * @see pga970_waveform.h
 */
/* ========================================================================== */
void WAVEFORM_Config(UC tableLength, US dacoffset, UC genCtrl)
{
    WAVEFORM_TABLE_LEN = tableLength;
    WAVEFORM_DAC_OFFSET = dacoffset;
    WAVEFORM_GEN_CTRL = genCtrl;
    /*Connect waveform output to Waveform gain*/
    AMUX_CTRL = ((AMUX_CTRL & ~0xF0) |
                 (WAVEFORM_DAC_OP_TO_WAVEFORM_GAIN & 0xF0));
}
#endif /*#if(WAVEFORM_TESTING==1)*/
