/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_fir.c
*
* This File contains code used for PGA970 FIR filter implementation.
*
* @path $(CSLPATH)\PGA970\source\lib
*
* @rev 1.3
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 06-June-2013 mf: Modified TusharB.Data types are modified as per type-def.
*!
*! 12-Apr-2013 mf: Modified ArunV. FIR_Filter function is added.
*!
*! 12-Apr-2013 mf: Modified TusharB. Branch from respective code base.
* =========================================================================== */

/*******************************************************************************
* INCLUDE FILES
*******************************************************************************/
#include "pga970_platf.h"

/* Filtered values of PADC and TADC are stored in the following variables */
VS2 FIR_FilteradcValue[2];
/* For filter implementation, need to accumulate PADC and TADC values */
VSL FIR_AccadcValue[2];


/* ========================================================================== */
/**
 * @fn FIR_Reset_Init() Initializes all FIR filter related global variables.
 *
 * @see pga970_fir.h
 */
/* ========================================================================== */
void FIR_Reset_Init(void)
{
   FIR_FilteradcValue[0] = 0;
   FIR_FilteradcValue[1] = 0;
   FIR_AccadcValue[0] = 0;
   FIR_AccadcValue[1] = 0;
}

/* ========================================================================== */
/**
 * @fn FIR_Filter() FIR filter function.
 *
 * @see pga970_fir.h
 */
/* ========================================================================== */
S2 FIR_Filter(UL numPoints, S2 newValue, SL *prevSum, S2 *valuePtr, UL *headIdx)
{
   SL sum;
   S2 retValue;

   sum = *prevSum - *(valuePtr + (*headIdx)) + newValue;
   *prevSum = sum;
   *(valuePtr + (*headIdx)) = newValue;
   /*
    * The following line is jitter free method to update headIdx
    * to between 0 and 2^numPoints - 1
    */
   *headIdx = (*headIdx + 1) & (((0x01 << numPoints) - 1));
   retValue = (S2)(sum >> numPoints);
   return(retValue);
}


