/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_app.h
*
* Header file for pga970_app.c
*
* @path $(CSLPATH)\PGA970\source\oem\inc
*
* @rev 1.3
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 08-Sept-2014 mf: Modified TusharB. Added DAC module related information.
* =========================================================================== */

#ifndef PGA970_APP_H
#define PGA970_APP_H

#ifdef __cplusplus
extern "C" {
#endif

#if(WATCH_DOG_TIMER_TESTING==1)
/* Watchdog trigger value  Watchdog time out value is (30 + 1) * 2ms = 62ms
 * Watchdog trigger value and Low trigger value shall be selected in such a way
 * that difference between this two values shall be more than time taken for
 * (DATARAM_MBIST + WRAM_MBIST + main loop) i.e
 * (38ms DATARAM_MBIST + 2ms WRAM MBIST + 8 ms = 48 ms)  */
#define APP_WATCHDOG_TIMEOUT 30

/* Watchdog low trigger value i.e. Low time out value is (2) * 2ms = 4ms
 * After 4ms only and before 62ms watchdog should be refreshed*/
#define APP_WATCHDOG_LOW_TIMEOUT 2

extern VUS WDOG_Low_Time_Cnt1;
extern VUS WDOG_Low_Time_Cnt2;
extern US WDOG_Trig_Low_Timeout;
#endif /*#if(WATCH_DOG_TIMER_TESTING==1)*/

/* Diag State */
extern UL Diag_State;

/* Diag Code */
extern UL Diag_Code;

extern SL HtempCoeff[2]; /* Calculated H Temperature coefficient value */
extern SL GtempCoeff[2]; /* Calculated G Temperature coefficient value */
extern SL NtempCoeff[2]; /* Calculated N Temperature coefficient value */
extern VUC VarI;         /* ping pong buffer index */
extern VUC VarJ;         /* ping pong buffer index */
extern UC FaultDiag;
extern US Coefficients_Calc_Sampling_Rate;
extern UC nFlags1;
extern FLOAT Gain;
extern FLOAT Offset;

#define nData_TABLE_OFFSET          0x600
#define nData_TABLE_SIZE_OFFSET     0x12
#define nData_TABLE_SIZE            16

/* ========================================================================== */
/**
 * APP_Reset_Init() Initializes global variables.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void APP_Reset_Init(void);

/* ========================================================================== */
/**
 * APP_Calculate_Coeff() State machine for T coefficient & P calculation.
 *
 * @param none
 *
 * @return none
 *
 * @post none
 *
 * @see none
 */
/* ========================================================================== */
void APP_Calculate_Coeff(void);

#ifdef __cplusplus
}
#endif

#endif /* PGA970_APP_H */
