/* =============================================================================
*                 Texas Instruments PGA970 Platform Software
* (c) Copyright Texas Instruments, Incorporated. All Rights Reserved.
*
* Use of this software is controlled by the terms and conditions found
* in the license agreement under which this software has been supplied.
* =========================================================================== */
/**
* @file pga970_cfg.c
*
* This File contains PGA970 application specific functions.
*
* @path $(CSLPATH)\PGA970\source\oem
*
* @rev 1.1
*/
/* -----------------------------------------------------------------------------
*!
*! Revision History
*! ===================================
*! 01-July-2013 mf: Modified TusharB. Application configuration file.
* =========================================================================== */

/*******************************************************************************
* INCLUDE FILES
*******************************************************************************/
#include "pga970_platf.h"
/* ========================================================================== */
/**
 * @fn CFG_Peripheral_Config() Configuration of PGA970 peripherals.
 *
 * @see pga970_cfg.h
 */
/* ========================================================================== */
void CFG_Peripheral_Config(void)
{
    /* Initialize all global variables */
    ADC_Reset_Init();
    FIR_Reset_Init();
    DAC_Reset_Init();

#if (COMBUF_TESTING == 1)
    COMBUF_Reset_Init();
#endif

    APP_Reset_Init();

    /* Read Coefficients from FRAM DATA */
    FRAM_DATA_Read_Coeff();

#if(WAVEFORM_TESTING==1)
    /* Read waveform table configurations from FRAM DATA */
    WAVEFORM_Read_Table();
#endif /*#if(WAVEFORM_TESTING==1)*/

    /* Configure frequency of PGA970 */
    M0_ConfigClock(CLK_8MHZ);

#if(DEVRAM_TESTING == 1)
    /* Copy code from FRAM to DEVRAM */
    REMAP_Config(REMAP_DISABLE);
    if (!(REMAP))
    {
      memcpy((void *)DEVRAM_START_ADDRESS,(void *)FRAM_TEXT_START_ADDRESS,FRAM_TEXT_AREA_SIZE);
      REMAP_Config(REMAP_ENABLE);
    }
#endif /*#if(DEVRAM_TESTING == 1)*/

#if (SYST_TESTING == 1)
   SYST_Config(SYSTICK_RELOAD_CNT, ST_CLKSOURCE | ST_TICKINT | ST_ENABLE);
#endif


    CONFIG_ALPWR(POWER_UP_PT_PGA_FD | ADC_EN_VREF | GATE_CTRL_SD_DISABLE);  //

    /* Configuring S1 Gain */
    S1_CONFIG(S1_GAIN_1_00_V_V | S1_GAIN_DIFFERENTIAL | NO_S1_INV);
    /* Configuring S2 Gain */
    S2_CONFIG(S2_GAIN_1_00_V_V | S2_GAIN_DIFFERENTIAL | NO_S2_INV);

    S1_S2_CONFIG(BIAS_VCM_CTRL_0_0 | VCM_ENABLE);

    /* Configuring VI Gain */
    S3_CONFIG( VI_GAIN_1_V_V);

    /* Configuring PTAT Gain */
    S3_CFG_1_CONFIG(NO_S3_OUTPUT_INV | PTAT_GAIN_1_V_V);

    /*Decimation Rate of DEMOD1 and DEMOD2 should be same*/
    ADC_Config(DEMOD1_EN | DEMOD1_DECI_RATE_128,
               DEMOD2_EN | DEMOD2_DECI_RATE_128,
               ADC3_EN,
               NO_S1_S2_RESET_MOD | NO_S1_S2_RESET_CLK |S1_S2_DEMOD_EN,
               NO_S3_RESET_MOD | NO_S3_RESET_CLK | S3_ADC_EN);

    DEMOD1_BPF_config(ADC12_BPF_CF5KHZ_B100HZ_B1,
                      ADC12_BPF_CF5KHZ_B100HZ_A2,
                      ADC12_BPF_CF5KHZ_B100HZ_A3);

    DEMOD1_LPF_config((S2)ADC12_LPF_CF100HZ_OP128US_B1,
                      (S2)ADC12_LPF_CF100HZ_OP128US_A2);

    DEMOD2_BPF_config(ADC12_BPF_CF5KHZ_B250HZ_B1,
                      ADC12_BPF_CF5KHZ_B250HZ_A2,
                      ADC12_BPF_CF5KHZ_B250HZ_A3);

    DEMOD2_LPF_config((S2)ADC12_LPF_CF20HZ_OP128US_B1,
                      (S2)ADC12_LPF_CF20HZ_OP128US_A2);

    ADC3_VI_LPF_Config((S2)ADC3_LPF_CF100HZ_B1, (S2)ADC3_LPF_CF100HZ_A2);

    ADC3_PTAT_LPF_Config((S2)ADC3_LPF_CF100HZ_B1, (S2)ADC3_LPF_CF100HZ_A2);

    DAC_Config(DAC_ENABLE,
               DAC_ABSOLUTE_MODE_ENABLE,
               GATE_3P3_CTRL_VDD_3_5_V | PULLUP_DISABLE | DACCAP_DISABLE |
               CL_4_20MA_DISABLE | DAC_GAIN_6_67_V_V);

    DAC_Loopback_Config(DAC_LOOPBACK_DISCONNECT |
                        DAC_LOOPBACK_AMPLIFIER_DISABLE | DAC_LOOPBACK_DISABLE);


#if (CCS_TESTING==1)
    /*Configure Constant current control of VDD*/
    CCS_Config((UC)(CONST_VDD_CURRENT_ENABLE | ADJ_CCS_10_1_MA));
#endif

#if(WAVEFORM_TESTING==1)
    LVDT_OP_CTRL_CONFIG(LVDT_SINGLE_ENDED_MODE | SKIP_FILTER_DISABLE |
                        LVDT_GAIN_CTRL_1_00_V_V | DIFF_VOCM_CTRL_0_75_V |
                        DACVCM_CTRL_0_82_V);

    LVDT_LPBK_CTRL_CONFIG(LVDT_LOOPBACK_DISCONNECT);

    WAVEFORM_Config(Waveform_Table_size,
                    (US)WAVEFORM_DAC_OFFSET_VAL,
                    WAVEFORM_GEN_ENABLE);
#endif /*#if(WAVEFORM_TESTING==1)*/


#if (GPIO_TESTING == 1)
   /* GPIO1 as output, push-pull */
  /* GPIO_Config(GPIO1_DIR_OUTPUT | GPIO2_DIR_INPUT,    // NJH 05/02/20 Changed to both high open drain outputs
               GPIO1_PUSH_PULL | GPIO2_OPEN_DRAIN);*/

    GPIO1_LOW();
    GPIO2_LOW();
    GPIO_Config(GPIO1_DIR_OUTPUT | GPIO2_DIR_OUTPUT,
                   GPIO1_OPEN_DRAIN | GPIO2_OPEN_DRAIN);
   /* Put value '1' on GPIO1, make GPIO1 as high */

#endif

    PIN_MUX_Config(GPIO_OP_GPIO_2_PIN_ENABLE);

#if (OWI_TESTING == 1)
   /* Configure Digital interface */
   DIGITAL_Interface_Config(SPI_ENABLE | OWI_ENABLE |OWI_DEGLITCH_FILTER_1MS);
   OWI_Config(OWI_INT_ENABLE);
#endif

#if (COMBUF_TESTING == 1)
   COMBUF_RX_INT_ENABLE();
#endif

#if (DIAGNOSTIC_TESTING == 1)
    AFEDIAG_CFG_CONFIG(S1_PULL_UP_ENABLE | S2_PULL_UP_ENABLE |
                       S3_PULL_UP_ENABLE | PE_PULL_UP_ENABLE);
#endif /*#if (DIAGNOSTIC_TESTING == 1)*/


#if (WATCH_DOG_TIMER_TESTING == 1)
    /* check if system is reset due to watchdog timer */
    if(WDT_TIMED_OUT())
    {
        /* Clear reset bit by writing '1' */
        WDT_RESET_CLEAR();
    }
    else
    {
        /* Enable software watchdog */
        WDT_TRIG_LOW_CONFIG(APP_WATCHDOG_LOW_TIMEOUT);
        WDT_TRIGGER(APP_WATCHDOG_TIMEOUT);
    }
#endif

     /*Check ADC decimation rate and calculate WDOG and main loop timings */
    if((DEMOD1_CONFIG & DEMOD1_DECI_RATE_256) == DEMOD1_DECI_RATE_256)
    {
        #if(WATCH_DOG_TIMER_TESTING==1)
        /*LOW trigger timeout, 1 ADC count  is 256us , so 1ms = 4count*/
        WDOG_Trig_Low_Timeout = ((APP_WATCHDOG_LOW_TIMEOUT*2)*4);
        #endif
        /*1 ADC count is 256us, so 2ms= 8 count*/
        Coefficients_Calc_Sampling_Rate = 0x0007;
    }
    else
    {
        #if(WATCH_DOG_TIMER_TESTING==1)
        /*LOW trigger timeout, 1 ADC count  is 128us, so 1ms = 8count*/
        WDOG_Trig_Low_Timeout = ((APP_WATCHDOG_LOW_TIMEOUT*2)*8);
        #endif
        /*1 ADC count is 128us, so 2ms= 16 count*/
        Coefficients_Calc_Sampling_Rate = 0x000F;
    }
    /* Initialize PGA970 interrupts */
    Interrupt_Config();

#if (WATCH_DOG_TIMER_TESTING == 1)
    /*Enable watchdog */
    WDT_ENABLE();
#endif

}
